"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
var TNSDOMMatrix_1 = require("./TNSDOMMatrix");
var canvas_plugin_common_1 = require("./canvas-plugin.common");
var TNSCanvasRenderingContext2D_1 = require("./TNSCanvasRenderingContext2D");
var TNSWebGLRenderingContext_1 = require("./TNSWebGLRenderingContext");
var TNSWebGL2RenderingContext_1 = require("./TNSWebGL2RenderingContext");
function createSVGMatrix() {
    return new TNSDOMMatrix_1.TNSDOMMatrix(Canvas.createSVGMatrix());
}
exports.createSVGMatrix = createSVGMatrix;
__export(require("./canvas-plugin.common"));
var TNSCanvas = (function (_super) {
    __extends(TNSCanvas, _super);
    function TNSCanvas() {
        var _this = _super.call(this) || this;
        _this.useMetal = false;
        _this._didPause = false;
        return _this;
    }
    Object.defineProperty(TNSCanvas.prototype, "clientWidth", {
        get: function () {
            return this.getMeasuredWidth();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvas.prototype, "clientHeight", {
        get: function () {
            return this.getMeasuredHeight();
        },
        enumerable: true,
        configurable: true
    });
    TNSCanvas.prototype.flush = function () {
        if (this.nativeView) {
            this.nativeView.flush();
        }
    };
    TNSCanvas.prototype.createNativeView = function () {
        return Canvas.alloc().initWithFrameUseGL(CGRectZero, !this.useMetal);
    };
    TNSCanvas.prototype.onUnloaded = function () {
        this.nativeView.pause();
        this._didPause = true;
        _super.prototype.onUnloaded.call(this);
    };
    TNSCanvas.prototype.onLoaded = function () {
        _super.prototype.onLoaded.call(this);
        if (this._didPause) {
            this.nativeView.resume();
            this._didPause = false;
        }
    };
    TNSCanvas.prototype.disposeNativeView = function () {
        this.off('touch, pan', this._touchEvents);
        _super.prototype.disposeNativeView.call(this);
    };
    TNSCanvas.prototype.getContext = function (type, options) {
        if (type && type === '2d') {
            if (!this._2dContext) {
                this._2dContext = new TNSCanvasRenderingContext2D_1.TNSCanvasRenderingContext2D(this.nativeView.getContextWithType(type));
                this._2dContext._canvas = this;
            }
            else {
                this.nativeView.getContextWithType(type);
            }
            this._2dContext._type = '2d';
            return this._2dContext;
        }
        else if (type && (type === 'webgl' || type === 'experimental-webgl')) {
            if (!this._webglContext) {
                this._webglContext = new TNSWebGLRenderingContext_1.TNSWebGLRenderingContext(this.nativeView.getContextWithType('webgl'));
                this._webglContext._canvas = this;
            }
            else {
                this.nativeView.getContextWithType(type);
            }
            this._webglContext._type = 'webgl';
            return this._webglContext;
        }
        else if (type && (type === 'webgl2')) {
            if (!this._webglContext) {
                this._webglContext = new TNSWebGL2RenderingContext_1.TNSWebGL2RenderingContext(this.nativeView.getContextWithType('webgl2'));
                this._webglContext._canvas = this;
            }
            else {
                this.nativeView.getContextWithType(type);
            }
            this._webglContext._type = 'webgl2';
            return this._webglContext;
        }
        return null;
    };
    TNSCanvas.prototype.toDataURL = function (type, encoderOptions) {
        if (type === void 0) { type = 'image/png'; }
        if (encoderOptions === void 0) { encoderOptions = 0.92; }
        return this.nativeView.toDataURLWithTypeFormat(type, encoderOptions);
    };
    TNSCanvas.prototype.getBoundingClientRect = function () {
        var view = this;
        var frame = view.ios.frame;
        var width = view.getMeasuredWidth();
        var height = view.getMeasuredHeight();
        return {
            bottom: height,
            height: height,
            left: frame.origin.x,
            right: width,
            top: frame.origin.y,
            width: width,
            x: frame.origin.x,
            y: frame.origin.y,
        };
    };
    return TNSCanvas;
}(canvas_plugin_common_1.TNSCanvasBase));
exports.TNSCanvas = TNSCanvas;
//# sourceMappingURL=TNSCanvas.ios.js.map