"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var canvas_plugin_common_1 = require("./canvas-plugin.common");
var fs = require("tns-core-modules/file-system");
var TNSImageAsset = (function (_super) {
    __extends(TNSImageAsset, _super);
    function TNSImageAsset() {
        return _super.call(this, new com.github.triniwiz.canvas.ImageAsset()) || this;
    }
    TNSImageAsset.prototype.loadFile = function (path) {
        var realPath = path;
        if (typeof realPath === 'string') {
            if (realPath.startsWith('~/')) {
                realPath = fs.path.join(fs.knownFolders.currentApp().path, realPath.replace('~/', ''));
            }
        }
        return this.native.loadImageFromPath(realPath);
    };
    TNSImageAsset.toPrimitive = function (value) {
        if (value instanceof java.lang.Integer) {
            return value.intValue();
        }
        else if (value instanceof java.lang.Long) {
            return value.longValue();
        }
        else if (value instanceof java.lang.Short) {
            return value.shortValue();
        }
        else if (value instanceof java.lang.Byte) {
            return value.byteValue();
        }
        else if (value instanceof java.lang.Boolean) {
            return value.booleanValue();
        }
        else if (value instanceof java.lang.String) {
            return value.toString();
        }
        else if (value instanceof java.lang.Float) {
            return value.floatValue();
        }
        else if (value instanceof java.lang.Double) {
            return value.doubleValue();
        }
        return value;
    };
    TNSImageAsset.prototype.loadFileAsync = function (path) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (typeof path === 'string') {
                if (path.startsWith('~/')) {
                    path = fs.path.join(fs.knownFolders.currentApp().path, path.replace('~/', ''));
                }
            }
            _this.native.loadImageFromPathAsync(path, new com.github.triniwiz.canvas.ImageAsset.Callback({
                onError: function (error) {
                    reject(error);
                },
                onSuccess: function (success) {
                    resolve(TNSImageAsset.toPrimitive(success));
                },
            }));
        });
    };
    TNSImageAsset.prototype.loadFromNative = function (image) {
        return this.native.loadImageFromImage(image);
    };
    TNSImageAsset.prototype.loadFromNativeAsync = function (image) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            _this.native.loadImageFromImageAsync(image, new com.github.triniwiz.canvas.ImageAsset.Callback({
                onError: function (error) {
                    reject(error);
                },
                onSuccess: function (success) {
                    resolve(TNSImageAsset.toPrimitive(success));
                },
            }));
        });
    };
    TNSImageAsset.prototype.loadFromBytes = function (bytes) {
        if (bytes instanceof Uint8Array || bytes instanceof Uint8ClampedArray) {
            var buf = java.nio.ByteBuffer.wrap(Array.from(bytes));
            return this.native.loadImageFromBytes(buf.array());
        }
        return this.native.loadImageFromBytes(bytes);
    };
    TNSImageAsset.prototype.loadFromBytesAsync = function (bytes) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var callback = new com.github.triniwiz.canvas.ImageAsset.Callback({
                onError: function (error) {
                    reject(error);
                },
                onSuccess: function (success) {
                    resolve(TNSImageAsset.toPrimitive(success));
                },
            });
            if (bytes instanceof Uint8Array || bytes instanceof Uint8ClampedArray) {
                var buf = java.nio.ByteBuffer.wrap(Array.from(bytes));
                _this.native.loadImageFromBytesAsync(buf.array(), callback);
            }
            else {
                _this.native.loadImageFromBytesAsync(bytes, callback);
            }
        });
    };
    Object.defineProperty(TNSImageAsset.prototype, "width", {
        get: function () {
            return this.native.getWidth();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSImageAsset.prototype, "height", {
        get: function () {
            return this.native.getHeight();
        },
        enumerable: true,
        configurable: true
    });
    TNSImageAsset.prototype.scale = function (x, y) {
        this.native.scale(x, y);
    };
    TNSImageAsset.prototype.save = function (path, format) {
        var realFormat;
        switch (format) {
            case canvas_plugin_common_1.TNSImageAssetSaveFormat.PNG:
                realFormat = com.github.triniwiz.canvas.ImageAssetFormat.PNG;
                break;
            case canvas_plugin_common_1.TNSImageAssetSaveFormat.ICO:
                realFormat = com.github.triniwiz.canvas.ImageAssetFormat.ICO;
                break;
            case canvas_plugin_common_1.TNSImageAssetSaveFormat.BMP:
                realFormat = com.github.triniwiz.canvas.ImageAssetFormat.BMP;
                break;
            case canvas_plugin_common_1.TNSImageAssetSaveFormat.TIFF:
                realFormat = com.github.triniwiz.canvas.ImageAssetFormat.TIFF;
                break;
            default:
                realFormat = com.github.triniwiz.canvas.ImageAssetFormat.JPG;
                break;
        }
        return this.native.save(path, realFormat);
    };
    TNSImageAsset.prototype.saveAsync = function (path, format) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var realFormat;
            switch (format) {
                case canvas_plugin_common_1.TNSImageAssetSaveFormat.PNG:
                    realFormat = com.github.triniwiz.canvas.ImageAssetFormat.PNG;
                    break;
                case canvas_plugin_common_1.TNSImageAssetSaveFormat.ICO:
                    realFormat = com.github.triniwiz.canvas.ImageAssetFormat.ICO;
                    break;
                case canvas_plugin_common_1.TNSImageAssetSaveFormat.BMP:
                    realFormat = com.github.triniwiz.canvas.ImageAssetFormat.BMP;
                    break;
                case canvas_plugin_common_1.TNSImageAssetSaveFormat.TIFF:
                    realFormat = com.github.triniwiz.canvas.ImageAssetFormat.TIFF;
                    break;
                default:
                    realFormat = com.github.triniwiz.canvas.ImageAssetFormat.JPG;
                    break;
            }
            _this.native.saveAsync(path, realFormat, new com.github.triniwiz.canvas.ImageAsset.Callback({
                onError: function (error) {
                    reject(error);
                },
                onSuccess: function (success) {
                    resolve(TNSImageAsset.toPrimitive(success));
                },
            }));
        });
    };
    TNSImageAsset.prototype.flipX = function () {
        this.native.flipX();
    };
    TNSImageAsset.prototype.flipY = function () {
        this.native.flipY();
    };
    Object.defineProperty(TNSImageAsset.prototype, "error", {
        get: function () {
            return this.native.getError();
        },
        enumerable: true,
        configurable: true
    });
    return TNSImageAsset;
}(canvas_plugin_common_1.TNSImageAssetBase));
exports.TNSImageAsset = TNSImageAsset;
//# sourceMappingURL=TNSImageAsset.android.js.map