"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var canvas_plugin_common_1 = require("./canvas-plugin.common");
var fs = require("tns-core-modules/file-system");
var main_queue = dispatch_get_current_queue();
var TNSImageAsset = (function (_super) {
    __extends(TNSImageAsset, _super);
    function TNSImageAsset() {
        return _super.call(this, ImageAsset.alloc().init()) || this;
    }
    TNSImageAsset.prototype._createQueue = function () {
        return dispatch_queue_create('TNSImageAsset', null);
    };
    TNSImageAsset.prototype.loadFile = function (path) {
        var realPath = path;
        if (typeof realPath === 'string') {
            if (realPath.startsWith('~/')) {
                realPath = fs.path.join(fs.knownFolders.currentApp().path, realPath.replace('~/', ''));
            }
        }
        return this.native.loadImageFromPathWithPath(realPath);
    };
    TNSImageAsset.prototype.loadFileAsync = function (path) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var queue = _this._createQueue();
            dispatch_async(queue, function () {
                var success = _this.loadFile(path);
                dispatch_async(main_queue, function () {
                    if (!success) {
                        reject(_this.error);
                        return;
                    }
                    resolve(true);
                });
            });
        });
    };
    TNSImageAsset.prototype.loadFromNative = function (image) {
        return this.native.loadImageFromImageWithImage(image);
    };
    TNSImageAsset.prototype.loadFromNativeAsync = function (image) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var queue = _this._createQueue();
            dispatch_async(queue, function () {
                var success = _this.loadFromNative(image);
                dispatch_async(main_queue, function () {
                    if (!success) {
                        reject(_this.error);
                        return;
                    }
                    resolve(true);
                });
            });
        });
    };
    TNSImageAsset.prototype.loadFromBytes = function (bytes) {
        return this.native.loadImageFromBytesWithArray(bytes);
    };
    TNSImageAsset.prototype.loadFromBytesAsync = function (bytes) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var queue = _this._createQueue();
            dispatch_async(queue, function () {
                var success = _this.loadFromBytes(bytes);
                dispatch_async(main_queue, function () {
                    if (!success) {
                        reject(_this.error);
                        return;
                    }
                    resolve(true);
                });
            });
        });
    };
    Object.defineProperty(TNSImageAsset.prototype, "width", {
        get: function () {
            return this.native.width;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSImageAsset.prototype, "height", {
        get: function () {
            return this.native.height;
        },
        enumerable: true,
        configurable: true
    });
    TNSImageAsset.prototype.scale = function (x, y) {
        this.native.scaleWithXY(x, y);
    };
    TNSImageAsset.prototype.save = function (path, format) {
        return this.native.saveWithPathFormat(path, format.valueOf());
    };
    TNSImageAsset.prototype.saveAsync = function (path, format) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var result = _this.save(path, format);
            dispatch_async(main_queue, function () {
                if (!result) {
                    reject(_this.error);
                    return;
                }
                resolve(result);
            });
        });
    };
    TNSImageAsset.prototype.flipX = function () {
        this.native.flipX();
    };
    TNSImageAsset.prototype.flipY = function () {
        this.native.flipY();
    };
    Object.defineProperty(TNSImageAsset.prototype, "error", {
        get: function () {
            return this.native.error;
        },
        enumerable: true,
        configurable: true
    });
    return TNSImageAsset;
}(canvas_plugin_common_1.TNSImageAssetBase));
exports.TNSImageAsset = TNSImageAsset;
//# sourceMappingURL=TNSImageAsset.ios.js.map