"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var canvas_plugin_common_1 = require("./canvas-plugin.common");
var image_source_1 = require("tns-core-modules/image-source");
var TNSWebGLExtensions_1 = require("./TNSWebGLExtensions");
var TNSImageAsset_1 = require("./TNSImageAsset");
var TNSWebGLRenderingContext = (function (_super) {
    __extends(TNSWebGLRenderingContext, _super);
    function TNSWebGLRenderingContext(context) {
        var _this = _super.call(this, context) || this;
        _this.context = context;
        return _this;
    }
    TNSWebGLRenderingContext.prototype.getJSArray = function (value) {
        var count = value.length;
        var array = [];
        for (var i = 0; i < count; i++) {
            array.push(value[i]);
        }
        return array;
    };
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "native", {
        get: function () {
            return this.context;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "drawingBufferHeight", {
        get: function () {
            return this.context.getDrawingBufferHeight();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "drawingBufferWidth", {
        get: function () {
            return this.context.getDrawingBufferWidth();
        },
        enumerable: true,
        configurable: true
    });
    TNSWebGLRenderingContext.prototype._glCheckError = function (message) {
        if (!TNSWebGLRenderingContext.isDebug) {
            return;
        }
        if (TNSWebGLRenderingContext.filter === 'both' || TNSWebGLRenderingContext.filter === 'error') {
            console.log(message, this.getError());
        }
    };
    TNSWebGLRenderingContext.prototype._checkArgs = function (message, args) {
        if (!TNSWebGLRenderingContext.isDebug) {
            return;
        }
        if (TNSWebGLRenderingContext.filter === 'both' || TNSWebGLRenderingContext.filter === 'args') {
            console.log('\/**** ', message, ' ****\/');
            console.dir(args);
            console.log('\/**** ', message, ' ****\/');
        }
    };
    TNSWebGLRenderingContext.prototype.activeTexture = function (texture) {
        this._glCheckError('activeTexture');
        this._checkArgs('activeTexture', arguments);
        this.context.activeTexture(texture);
    };
    TNSWebGLRenderingContext.prototype.attachShader = function (program, shader) {
        this._glCheckError('attachShader');
        this._checkArgs('attachShader', arguments);
        var value = program ? program.native : null;
        var value2 = shader ? shader.native : null;
        this.context.attachShader(value, value2);
    };
    TNSWebGLRenderingContext.prototype.bindAttribLocation = function (program, index, name) {
        this._glCheckError('bindAttribLocation');
        this._checkArgs('bindAttribLocation', arguments);
        var value = program ? program.native : null;
        this.context.bindAttribLocation(value, index, name);
    };
    TNSWebGLRenderingContext.prototype.bindBuffer = function (target, buffer) {
        this._glCheckError('bindBuffer');
        this._checkArgs('bindBuffer', arguments);
        var value = buffer ? buffer.native : null;
        this.context.bindBuffer(target, value);
    };
    TNSWebGLRenderingContext.prototype.bindFramebuffer = function (target, framebuffer) {
        this._glCheckError('bindFramebuffer');
        this._checkArgs('bindFramebuffer', arguments);
        var value = framebuffer ? framebuffer.native : null;
        this.context.bindFramebuffer(target, value);
    };
    TNSWebGLRenderingContext.prototype.bindRenderbuffer = function (target, renderbuffer) {
        this._glCheckError('bindRenderbuffer');
        this._checkArgs('bindRenderbuffer', arguments);
        var value = renderbuffer ? renderbuffer.native : null;
        this.context.bindRenderbuffer(target, value);
    };
    TNSWebGLRenderingContext.prototype.bindTexture = function (target, texture) {
        this._glCheckError('bindTexture');
        this._checkArgs('bindTexture', arguments);
        var value = texture ? texture.native : null;
        this.context.bindTexture(target, value);
    };
    TNSWebGLRenderingContext.prototype.blendColor = function (red, green, blue, alpha) {
        this._glCheckError('blendColor');
        this._checkArgs('blendColor', arguments);
        this.context.blendColor(red, green, blue, alpha);
    };
    TNSWebGLRenderingContext.prototype.blendEquationSeparate = function (modeRGB, modeAlpha) {
        this._glCheckError('blendEquationSeparate');
        this._checkArgs('blendEquationSeparate', arguments);
        this.context.blendEquationSeparate(modeRGB, modeAlpha);
    };
    TNSWebGLRenderingContext.prototype.blendEquation = function (mode) {
        this._glCheckError('blendEquation');
        this._checkArgs('blendEquation', arguments);
        this.context.blendEquation(mode);
    };
    TNSWebGLRenderingContext.prototype.blendFuncSeparate = function (srcRGB, dstRGB, srcAlpha, dstAlpha) {
        if (srcRGB === void 0) { srcRGB = this.ONE; }
        if (dstRGB === void 0) { dstRGB = this.ZERO; }
        if (srcAlpha === void 0) { srcAlpha = this.ONE; }
        if (dstAlpha === void 0) { dstAlpha = this.ZERO; }
        this._glCheckError('blendFuncSeparate');
        this._checkArgs('blendFuncSeparate', arguments);
        this.context.blendFuncSeparate(srcRGB, dstRGB, srcAlpha, dstAlpha);
    };
    TNSWebGLRenderingContext.prototype.blendFunc = function (sfactor, dfactor) {
        if (sfactor === void 0) { sfactor = this.ONE; }
        if (dfactor === void 0) { dfactor = this.ZERO; }
        this._glCheckError('blendFunc');
        this._checkArgs('blendFunc', arguments);
        this.context.blendFunc(sfactor, dfactor);
    };
    TNSWebGLRenderingContext.prototype.toNativeArray = function (value, type) {
        if (value && value.length && typeof type === 'string') {
            var size = value.length;
            var nativeArray = Array.create(type, size);
            for (var i = 0; i < size; i++) {
                nativeArray[i] = value[i];
            }
            return nativeArray;
        }
        return [];
    };
    TNSWebGLRenderingContext.prototype.bufferData = function (target, srcData, usage) {
        this._glCheckError('bufferData');
        this._checkArgs('bufferData', arguments);
        if (typeof srcData === 'number') {
            this.context.bufferData(target, srcData, usage);
        }
        else if (srcData instanceof ArrayBuffer) {
            this.context.bufferData(target, this.toNativeArray(new Uint8Array(srcData.slice(0)), 'byte'), usage);
        }
        else if (srcData && srcData.buffer instanceof ArrayBuffer) {
            if (srcData instanceof Uint8Array) {
                this.context.bufferData(target, this.toNativeArray(srcData, 'byte'), usage);
            }
            else if (srcData instanceof Uint16Array || srcData instanceof Int16Array) {
                this.context.bufferData(target, this.toNativeArray(srcData, 'short'), usage);
            }
            else if (srcData instanceof Uint32Array || srcData instanceof Int32Array) {
                this.context.bufferData(target, this.toNativeArray(srcData, 'int'), usage);
            }
            else if (srcData instanceof Float32Array) {
                this.context.bufferData(target, this.toNativeArray(srcData, 'float'), usage);
            }
        }
    };
    TNSWebGLRenderingContext.prototype.bufferSubData = function (target, offset, srcData) {
        this._glCheckError('bufferSubData');
        this._checkArgs('bufferSubData', arguments);
        if (srcData instanceof ArrayBuffer) {
            this.context.bufferSubData(target, offset, new Uint8Array(srcData.slice(0)));
        }
        else if (srcData && srcData.buffer instanceof ArrayBuffer) {
            if (srcData instanceof Uint8Array) {
                this.context.bufferSubData(target, offset, this.toNativeArray(srcData, 'byte'));
            }
            else if (srcData instanceof Uint16Array || srcData instanceof Int16Array) {
                this.context.bufferSubData(target, offset, this.toNativeArray(srcData, 'short'));
            }
            else if (srcData instanceof Uint32Array || srcData instanceof Int32Array) {
                this.context.bufferSubData(target, offset, this.toNativeArray(srcData, 'int'));
            }
            else if (srcData instanceof Float32Array) {
                this.context.bufferSubData(target, offset, this.toNativeArray(srcData, 'float'));
            }
        }
    };
    TNSWebGLRenderingContext.prototype.checkFramebufferStatus = function (target) {
        this._glCheckError('checkFramebufferStatus');
        this._checkArgs('checkFramebufferStatus', arguments);
        return this.context.checkFramebufferStatus(target);
    };
    TNSWebGLRenderingContext.prototype.clearColor = function (red, green, blue, alpha) {
        this._glCheckError('clearColor');
        this._checkArgs('clearColor', arguments);
        this.context.clearColor(red, green, blue, alpha);
    };
    TNSWebGLRenderingContext.prototype.clearDepth = function (depth) {
        this._glCheckError('clearDepth');
        this._checkArgs('clearDepth', arguments);
        this.context.clearDepth(depth);
    };
    TNSWebGLRenderingContext.prototype.clearStencil = function (stencil) {
        this._glCheckError('clearStencil');
        this._checkArgs('clearStencil', arguments);
        this.context.clearStencil(stencil);
    };
    TNSWebGLRenderingContext.prototype.clear = function (mask) {
        this._glCheckError('clear');
        this._checkArgs('clear', arguments);
        this.context.clear(mask);
    };
    TNSWebGLRenderingContext.prototype.colorMask = function (red, green, blue, alpha) {
        this._glCheckError('colorMask');
        this._checkArgs('colorMask', arguments);
        this.context.colorMask(red, green, blue, alpha);
    };
    TNSWebGLRenderingContext.prototype.commit = function () {
        this.context.commit();
    };
    TNSWebGLRenderingContext.prototype.compileShader = function (shader) {
        this._glCheckError('compileShader');
        this._checkArgs('compileShader', arguments);
        var value = shader ? shader.native : null;
        this.context.compileShader(value);
    };
    TNSWebGLRenderingContext.prototype.compressedTexImage2D = function (target, level, internalformat, width, height, border, pixels) {
        this._glCheckError('compressedTexImage2D');
        this._checkArgs('compressedTexImage2D', arguments);
        if (pixels && pixels.buffer instanceof ArrayBuffer) {
            if (pixels instanceof Uint8Array) {
                this.context.compressedTexImage2D(target, level, internalformat, width, height, border, this.toNativeArray(pixels, 'byte'));
            }
            else if (pixels instanceof Uint16Array || pixels instanceof Int16Array) {
                this.context.compressedTexImage2D(target, level, internalformat, width, height, border, this.toNativeArray(pixels, 'short'));
            }
            else if (pixels instanceof Uint32Array || pixels instanceof Int32Array) {
                this.context.compressedTexImage2D(target, level, internalformat, width, height, border, this.toNativeArray(pixels, 'int'));
            }
            else if (pixels instanceof Float32Array) {
                this.context.compressedTexImage2D(target, level, internalformat, width, height, border, this.toNativeArray(pixels, 'float'));
            }
        }
        else if (pixels instanceof ArrayBuffer) {
            this.context.compressedTexImage2D(target, level, internalformat, width, height, border, this.toNativeArray(new Uint8Array(pixels.slice(0)), 'byte'));
        }
    };
    TNSWebGLRenderingContext.prototype.compressedTexSubImage2D = function (target, level, xoffset, yoffset, width, height, format, pixels) {
        this._glCheckError('compressedTexSubImage2D');
        this._checkArgs('compressedTexSubImage2D', arguments);
        if (pixels && pixels.buffer instanceof ArrayBuffer) {
            if (pixels instanceof Uint8Array) {
                this.context.compressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, this.toNativeArray(pixels, 'byte'));
            }
            else if (pixels instanceof Uint16Array || pixels instanceof Int16Array) {
                this.context.compressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, this.toNativeArray(pixels, 'short'));
            }
            else if (pixels instanceof Uint32Array || pixels instanceof Int32Array) {
                this.context.compressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, this.toNativeArray(pixels, 'int'));
            }
            else if (pixels instanceof Float32Array) {
                this.context.compressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, this.toNativeArray(pixels, 'float'));
            }
        }
        else if (pixels instanceof ArrayBuffer) {
            this.context.compressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, this.toNativeArray(new Uint8Array(pixels.slice(0)), 'byte'));
        }
    };
    TNSWebGLRenderingContext.prototype.copyTexImage2D = function (target, level, internalformat, x, y, width, height, border) {
        this._glCheckError('copyTexImage2D');
        this._checkArgs('copyTexImage2D', arguments);
        this.context.copyTexImage2D(target, level, internalformat, x, y, width, height, border);
    };
    TNSWebGLRenderingContext.prototype.copyTexSubImage2D = function (target, level, xoffset, yoffset, x, y, width, height) {
        this._glCheckError('copyTexSubImage2D');
        this._checkArgs('copyTexSubImage2D', arguments);
        this.context.copyTexSubImage2D(target, level, xoffset, yoffset, x, y, width, height);
    };
    TNSWebGLRenderingContext.prototype.createBuffer = function () {
        this._glCheckError('createBuffer');
        this._checkArgs('createBuffer', arguments);
        var id = this.context.createBuffer();
        return new canvas_plugin_common_1.WebGLBuffer(id);
    };
    TNSWebGLRenderingContext.prototype.createFramebuffer = function () {
        this._glCheckError('createFramebuffer');
        this._checkArgs('createFramebuffer', arguments);
        return new canvas_plugin_common_1.WebGLFramebuffer(this.context.createFramebuffer());
    };
    TNSWebGLRenderingContext.prototype.createProgram = function () {
        this._glCheckError('createProgram');
        this._checkArgs('createProgram', arguments);
        return new canvas_plugin_common_1.WebGLProgram(this.context.createProgram());
    };
    TNSWebGLRenderingContext.prototype.createRenderbuffer = function () {
        this._glCheckError('createRenderbuffer');
        this._checkArgs('createRenderbuffer', arguments);
        return new canvas_plugin_common_1.WebGLRenderbuffer(this.context.createRenderbuffer());
    };
    TNSWebGLRenderingContext.prototype.createShader = function (type) {
        this._glCheckError('createShader');
        this._checkArgs('createShader', arguments);
        return new canvas_plugin_common_1.WebGLShader(this.context.createShader(type));
    };
    TNSWebGLRenderingContext.prototype.createTexture = function () {
        this._glCheckError('createTexture');
        this._checkArgs('createTexture', arguments);
        return new canvas_plugin_common_1.WebGLTexture(this.context.createTexture());
    };
    TNSWebGLRenderingContext.prototype.cullFace = function (mode) {
        this._glCheckError('cullFace');
        this._checkArgs('cullFace', arguments);
        this.context.cullFace(mode);
    };
    TNSWebGLRenderingContext.prototype.deleteBuffer = function (buffer) {
        this._glCheckError('deleteBuffer');
        this._checkArgs('deleteBuffer', arguments);
        var value = buffer ? buffer.native : null;
        this.context.deleteBuffer(value);
    };
    TNSWebGLRenderingContext.prototype.deleteFramebuffer = function (frameBuffer) {
        this._glCheckError('deleteFramebuffer');
        this._checkArgs('deleteFramebuffer', arguments);
        var value = frameBuffer ? frameBuffer.native : null;
        this.context.deleteFramebuffer(value);
    };
    TNSWebGLRenderingContext.prototype.deleteProgram = function (program) {
        this._glCheckError('deleteProgram');
        this._checkArgs('deleteProgram', arguments);
        var value = program ? program.native : null;
        this.context.deleteProgram(value);
    };
    TNSWebGLRenderingContext.prototype.deleteRenderbuffer = function (renderBuffer) {
        this._glCheckError('deleteRenderbuffer');
        this._checkArgs('deleteRenderbuffer', arguments);
        var value = renderBuffer ? renderBuffer.native : null;
        this.context.deleteRenderbuffer(value);
    };
    TNSWebGLRenderingContext.prototype.deleteShader = function (shader) {
        this._glCheckError('deleteShader');
        this._checkArgs('deleteShader', arguments);
        var value = shader ? shader.native : null;
        this.context.deleteShader(value);
    };
    TNSWebGLRenderingContext.prototype.deleteTexture = function (texture) {
        this._glCheckError('deleteTexture');
        this._checkArgs('deleteTexture', arguments);
        var value = texture ? texture.native : null;
        this.context.deleteTexture(value);
    };
    TNSWebGLRenderingContext.prototype.depthFunc = function (func) {
        this._glCheckError('depthFunc');
        this._checkArgs('depthFunc', arguments);
        this.context.depthFunc(func);
    };
    TNSWebGLRenderingContext.prototype.depthMask = function (flag) {
        this._glCheckError('depthMask');
        this._checkArgs('depthMask', arguments);
        this.context.depthMask(flag);
    };
    TNSWebGLRenderingContext.prototype.depthRange = function (zNear, zFar) {
        this._glCheckError('depthRange');
        this._checkArgs('depthRange', arguments);
        this.context.depthRange(zNear, zFar);
    };
    TNSWebGLRenderingContext.prototype.detachShader = function (program, shader) {
        this._glCheckError('detachShader');
        this._checkArgs('detachShader', arguments);
        var value = program ? program.native : null;
        var value2 = shader ? shader.native : null;
        this.context.detachShader(value, value2);
    };
    TNSWebGLRenderingContext.prototype.disableVertexAttribArray = function (index) {
        this._glCheckError('disableVertexAttribArray');
        this._checkArgs('disableVertexAttribArray', arguments);
        this.context.disableVertexAttribArray(index);
    };
    TNSWebGLRenderingContext.prototype.disable = function (cap) {
        this._glCheckError('disable');
        this._checkArgs('disable', arguments);
        this.context.disable(cap);
    };
    TNSWebGLRenderingContext.prototype.drawArrays = function (mode, first, count) {
        this._glCheckError('drawArrays');
        this._checkArgs('drawArrays', arguments);
        this.context.drawArrays(mode, first, count);
    };
    TNSWebGLRenderingContext.prototype.drawElements = function (mode, count, type, offset) {
        this._glCheckError('drawElements');
        this._checkArgs('drawElements', arguments);
        this.context.drawElements(mode, count, type, offset);
    };
    TNSWebGLRenderingContext.prototype.enableVertexAttribArray = function (index) {
        this._glCheckError('enableVertexAttribArray');
        this._checkArgs('enableVertexAttribArray', arguments);
        this.context.enableVertexAttribArray(index);
    };
    TNSWebGLRenderingContext.prototype.enable = function (cap) {
        this._glCheckError('enable');
        this._checkArgs('enableframebufferTexture2D', arguments);
        this.context.enable(cap);
    };
    TNSWebGLRenderingContext.prototype.finish = function () {
        this._glCheckError('finish');
        this.context.finish();
    };
    TNSWebGLRenderingContext.prototype.flush = function () {
        this._glCheckError('flush');
        this.context.flush();
    };
    TNSWebGLRenderingContext.prototype.framebufferRenderbuffer = function (target, attachment, renderbuffertarget, renderbuffer) {
        this._glCheckError('framebufferRenderbuffer');
        this._checkArgs('framebufferRenderbuffer', arguments);
        var value = renderbuffer ? renderbuffer.native : null;
        this.context.framebufferRenderbuffer(target, attachment, renderbuffertarget, value);
    };
    TNSWebGLRenderingContext.prototype.framebufferTexture2D = function (target, attachment, textarget, texture, level) {
        this._glCheckError('framebufferTexture2D');
        this._checkArgs('activeTexture', arguments);
        var value = texture ? texture.native : null;
        this.context.framebufferTexture2D(target, attachment, textarget, value, level);
    };
    TNSWebGLRenderingContext.prototype.frontFace = function (mode) {
        this._checkArgs('activeTexture', arguments);
        this._glCheckError('activeTexture');
        this.context.frontFace(mode);
    };
    TNSWebGLRenderingContext.prototype.generateMipmap = function (target) {
        this._checkArgs('activeTexture', arguments);
        this._glCheckError('activeTexture');
        this.context.generateMipmap(target);
    };
    TNSWebGLRenderingContext.prototype.getActiveAttrib = function (program, index) {
        this._glCheckError('getActiveAttrib');
        this._checkArgs('getActiveAttrib', arguments);
        var value = program ? program.native : null;
        var attrib = this.context.getActiveAttrib(value, index);
        return new canvas_plugin_common_1.WebGLActiveInfo(attrib.getName(), attrib.getSize(), attrib.getType());
    };
    TNSWebGLRenderingContext.prototype.getActiveUniform = function (program, index) {
        this._glCheckError('getActiveUniform');
        this._checkArgs('getActiveUniform', arguments);
        var value = program ? program.native : null;
        var uniform = this.context.getActiveUniform(value, index);
        return new canvas_plugin_common_1.WebGLActiveInfo(uniform.getName(), uniform.getSize(), uniform.getType());
    };
    TNSWebGLRenderingContext.prototype.getAttachedShaders = function (program) {
        this._glCheckError('getAttachedShaders');
        this._checkArgs('getAttachedShaders', arguments);
        var value = program ? program.native : null;
        return this.getJSArray(this.context.getAttachedShaders(value)).map(function (shader) { return new canvas_plugin_common_1.WebGLShader(shader); });
    };
    TNSWebGLRenderingContext.prototype.getAttribLocation = function (program, name) {
        this._glCheckError('getAttribLocation');
        this._checkArgs('getAttribLocation', arguments);
        var value = program ? program.native : null;
        return this.context.getAttribLocation(value, name);
    };
    TNSWebGLRenderingContext.prototype.getBufferParameter = function (target, pname) {
        this._glCheckError('getBufferParameter');
        this._checkArgs('getBufferParameter', arguments);
        return this.context.getBufferParameter(target, pname);
    };
    TNSWebGLRenderingContext.prototype.getContextAttributes = function () {
        var attributes = this.context.getContextAttributes();
        var keys = attributes.keySet().toArray();
        var length = keys.length;
        var contextAttributes = {};
        for (var i = 0; i < length; i++) {
            var key = keys[i];
            contextAttributes[key] = attributes.get(key);
        }
        return contextAttributes;
    };
    TNSWebGLRenderingContext.prototype.getError = function () {
        return this.context.getError();
    };
    TNSWebGLRenderingContext.prototype.getExtension = function (name) {
        this._glCheckError('getExtension');
        this._checkArgs('getExtension', arguments);
        if (name === 'EXT_disjoint_timer_query_webgl2') {
            return null;
        }
        var ext = this.context.getExtension(name);
        if (ext) {
            var clazz = ext && ext.getClass();
            var classObjName = clazz && clazz.getName();
            switch (classObjName) {
                case 'com.github.triniwiz.canvas.extensions.ANGLE_instanced_arrays':
                    return new TNSWebGLExtensions_1.ANGLE_instanced_arrays(ext);
                case 'com.github.triniwiz.canvas.extensions.EXT_blend_minmax':
                    return new TNSWebGLExtensions_1.EXT_blend_minmax(ext);
                case 'com.github.triniwiz.canvas.extensions.EXT_color_buffer_half_float':
                    return new TNSWebGLExtensions_1.EXT_color_buffer_half_float(ext);
                case 'com.github.triniwiz.canvas.extensions.EXT_disjoint_timer_query':
                    return null;
                case 'com.github.triniwiz.canvas.extensions.EXT_sRGB':
                    return new TNSWebGLExtensions_1.EXT_sRGB(ext);
                case 'com.github.triniwiz.canvas.extensions.EXT_shader_texture_lod':
                    return new TNSWebGLExtensions_1.EXT_shader_texture_lod(ext);
                case 'com.github.triniwiz.canvas.extensions.EXT_texture_filter_anisotropic':
                    return new TNSWebGLExtensions_1.EXT_texture_filter_anisotropic(ext);
                case 'com.github.triniwiz.canvas.extensions.OES_element_index_uint':
                    return new TNSWebGLExtensions_1.OES_element_index_uint(ext);
                case 'com.github.triniwiz.canvas.extensions.OES_standard_derivatives':
                    return new TNSWebGLExtensions_1.OES_standard_derivatives(ext);
                case 'com.github.triniwiz.canvas.extensions.OES_texture_float':
                    return new TNSWebGLExtensions_1.OES_texture_float(ext);
                case 'com.github.triniwiz.canvas.extensions.OES_texture_float_linear':
                    return new TNSWebGLExtensions_1.OES_texture_float_linear(ext);
                case 'com.github.triniwiz.canvas.extensions.OES_texture_half_float':
                    return new TNSWebGLExtensions_1.OES_texture_half_float(ext);
                case 'com.github.triniwiz.canvas.extensions.OES_texture_half_float_linear':
                    return new TNSWebGLExtensions_1.OES_texture_half_float_linear(ext);
                case 'com.github.triniwiz.canvas.extensions.OES_vertex_array_object':
                    return new TNSWebGLExtensions_1.OES_vertex_array_object(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_color_buffer_float':
                    return new TNSWebGLExtensions_1.WEBGL_color_buffer_float(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_compressed_texture_atc':
                    return new TNSWebGLExtensions_1.WEBGL_compressed_texture_atc(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_compressed_texture_etc':
                    return new TNSWebGLExtensions_1.WEBGL_compressed_texture_etc(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_compressed_texture_etc1':
                    return new TNSWebGLExtensions_1.WEBGL_compressed_texture_etc1(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_compressed_texture_pvrtc':
                    return new TNSWebGLExtensions_1.WEBGL_compressed_texture_pvrtc(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_compressed_texture_s3tc':
                    return new TNSWebGLExtensions_1.WEBGL_compressed_texture_s3tc(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_lose_context':
                    return new TNSWebGLExtensions_1.WEBGL_lose_context(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_depth_texture':
                    return new TNSWebGLExtensions_1.WEBGL_depth_texture(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_draw_buffers':
                    return new TNSWebGLExtensions_1.WEBGL_draw_buffers(ext);
            }
        }
        return null;
    };
    TNSWebGLRenderingContext.prototype.getFramebufferAttachmentParameter = function (target, attachment, pname) {
        this._glCheckError('getFramebufferAttachmentParameter');
        this._checkArgs('getFramebufferAttachmentParameter', arguments);
        var param = this.context.getFramebufferAttachmentParameter(target, attachment, pname);
        if (param.isRenderbuffer()) {
            return new canvas_plugin_common_1.WebGLRenderbuffer(param.getValue());
        }
        else if (param.isTexture()) {
            return new canvas_plugin_common_1.WebGLTexture(param.getValue());
        }
        return TNSWebGLRenderingContext.toPrimitive(param.getValue());
    };
    TNSWebGLRenderingContext.prototype.getParameter = function (pname) {
        this._glCheckError('getParameter');
        this._checkArgs('activeTexture', arguments);
        var value = this.context.getParameter(pname);
        switch (pname) {
            case this.COLOR_WRITEMASK:
            case this.COLOR_CLEAR_VALUE:
            case this.BLEND_COLOR:
            case this.ALIASED_LINE_WIDTH_RANGE:
            case this.ALIASED_POINT_SIZE_RANGE:
            case this.DEPTH_RANGE:
                return this.getJSArray(value);
            case this.ARRAY_BUFFER_BINDING:
            case this.ELEMENT_ARRAY_BUFFER_BINDING:
                return new canvas_plugin_common_1.WebGLBuffer(value);
            case this.CURRENT_PROGRAM:
                return new canvas_plugin_common_1.WebGLProgram(value);
            case this.COMPRESSED_TEXTURE_FORMATS:
                return new Uint32Array(this.getJSArray(value));
            case this.RENDERBUFFER_BINDING:
                return new canvas_plugin_common_1.WebGLRenderbuffer(value);
            case this.FRAMEBUFFER_BINDING:
                if (value) {
                    return new canvas_plugin_common_1.WebGLFramebuffer(value);
                }
                return null;
            case this.VIEWPORT:
            case this.SCISSOR_BOX:
            case this.MAX_VIEWPORT_DIMS:
                return new Int32Array(this.getJSArray(value));
            case this.TEXTURE_BINDING_CUBE_MAP:
            case this.TEXTURE_BINDING_2D:
                if (value) {
                    return new canvas_plugin_common_1.WebGLTexture(value);
                }
                return null;
            default:
                return value;
        }
    };
    TNSWebGLRenderingContext.prototype.getProgramInfoLog = function (program) {
        this._glCheckError('getProgramInfoLog');
        this._checkArgs('getProgramInfoLog', arguments);
        var value = program ? program.native : null;
        return this.context.getProgramInfoLog(value);
    };
    TNSWebGLRenderingContext.prototype.getProgramParameter = function (program, pname) {
        this._glCheckError('getProgramParameter');
        this._checkArgs('getProgramParameter', arguments);
        var value = program ? program.native : null;
        return TNSWebGLRenderingContext.toPrimitive(this.context.getProgramParameter(value, pname));
    };
    TNSWebGLRenderingContext.prototype.getRenderbufferParameter = function (target, pname) {
        this._glCheckError('getRenderbufferParameter');
        this._checkArgs('getRenderbufferParameter', arguments);
        return this.context.getRenderbufferParameter(target, pname);
    };
    TNSWebGLRenderingContext.prototype.getShaderInfoLog = function (shader) {
        this._glCheckError('getShaderInfoLog');
        this._checkArgs('getShaderInfoLog', arguments);
        var value = shader ? shader.native : null;
        return this.context.getShaderInfoLog(value);
    };
    TNSWebGLRenderingContext.toPrimitive = function (value) {
        if (value instanceof java.lang.Integer) {
            return value.intValue();
        }
        else if (value instanceof java.lang.Long) {
            return value.longValue();
        }
        else if (value instanceof java.lang.Short) {
            return value.shortValue();
        }
        else if (value instanceof java.lang.Byte) {
            return value.byteValue();
        }
        else if (value instanceof java.lang.Boolean) {
            return value.booleanValue();
        }
        else if (value instanceof java.lang.String) {
            return value.toString();
        }
        else if (value instanceof java.lang.Float) {
            return value.floatValue();
        }
        else if (value instanceof java.lang.Double) {
            return value.doubleValue();
        }
        return value;
    };
    TNSWebGLRenderingContext.prototype.getShaderParameter = function (shader, pname) {
        this._glCheckError('getShaderParameter');
        this._checkArgs('getShaderParameter', arguments);
        var value = shader ? shader.native : null;
        return TNSWebGLRenderingContext.toPrimitive(this.context.getShaderParameter(value, pname));
    };
    TNSWebGLRenderingContext.prototype.getShaderPrecisionFormat = function (shaderType, precisionType) {
        this._glCheckError('getShaderPrecisionFormat');
        this._checkArgs('getShaderPrecisionFormat', arguments);
        var precision = this.context.getShaderPrecisionFormat(shaderType, precisionType);
        return new canvas_plugin_common_1.WebGLShaderPrecisionFormat(precision.getRangeMin(), precision.getRangeMax(), precision.getPrecision());
    };
    TNSWebGLRenderingContext.prototype.getShaderSource = function (shader) {
        this._glCheckError('getShaderSource');
        this._checkArgs('getShaderSource', arguments);
        var value = shader ? shader.native : null;
        return this.context.getShaderSource(value);
    };
    TNSWebGLRenderingContext.prototype.getSupportedExtensions = function () {
        this._glCheckError('getSupportedExtensions');
        return this.getJSArray(this.context.getSupportedExtensions());
    };
    TNSWebGLRenderingContext.prototype.getTexParameter = function (target, pname) {
        this._glCheckError('getTexParameter');
        this._checkArgs('getTexParameter', arguments);
        return this.context.getTexParameter(target, pname);
    };
    TNSWebGLRenderingContext.prototype.getUniformLocation = function (program, name) {
        this._glCheckError('getUniformLocation');
        this._checkArgs('getUniformLocation', arguments);
        var value = program ? program.native : null;
        var id = this.context.getUniformLocation(value, name);
        if (id === -1) {
            return null;
        }
        ;
        return new canvas_plugin_common_1.WebGLUniformLocation(id);
    };
    TNSWebGLRenderingContext.prototype.getUniform = function (program, location) {
        this._glCheckError('getUniform');
        this._checkArgs('getUniform', arguments);
        var value = program ? program.native : null;
        var value2 = location ? location.native : null;
        var uniform = this.context.getUniform(value, value2);
        if (uniform && uniform.length) {
            return this.getJSArray(uniform);
        }
        return uniform;
    };
    TNSWebGLRenderingContext.prototype.getVertexAttribOffset = function (index, pname) {
        this._glCheckError('getVertexAttribOffset');
        this._checkArgs('getVertexAttribOffset', arguments);
        return this.context.getVertexAttribOffset(index, pname);
    };
    TNSWebGLRenderingContext.prototype.getVertexAttrib = function (index, pname) {
        this._glCheckError('getVertexAttrib');
        this._checkArgs('getVertexAttrib', arguments);
        var value = this.context.getVertexAttrib(index, pname);
        if (pname === this.CURRENT_VERTEX_ATTRIB) {
            return this.getJSArray(value);
        }
        return value;
    };
    TNSWebGLRenderingContext.prototype.hint = function (target, mode) {
        this._glCheckError('hint');
        this._checkArgs('hint', arguments);
        this.context.hint(target, mode);
    };
    TNSWebGLRenderingContext.prototype.isBuffer = function (buffer) {
        this._glCheckError('isBuffer');
        this._checkArgs('isBuffer', arguments);
        var value = buffer ? buffer.native : null;
        return this.context.isBuffer(value);
    };
    TNSWebGLRenderingContext.prototype.isContextLost = function () {
        this._glCheckError('isContextLost');
        return this.context.isContextLost();
    };
    TNSWebGLRenderingContext.prototype.isEnabled = function (cap) {
        this._glCheckError('isEnabled');
        this._checkArgs('isEnabled', arguments);
        return this.context.isEnabled(cap);
    };
    TNSWebGLRenderingContext.prototype.isFramebuffer = function (framebuffer) {
        this._glCheckError('isFramebuffer');
        this._checkArgs('isFramebuffer', arguments);
        var value = framebuffer ? framebuffer.native : null;
        return this.context.isFramebuffer(value);
    };
    TNSWebGLRenderingContext.prototype.isProgram = function (program) {
        this._glCheckError('isProgram');
        this._checkArgs('isProgram', arguments);
        var value = program ? program.native : null;
        return this.context.isProgram(value);
    };
    TNSWebGLRenderingContext.prototype.isRenderbuffer = function (renderbuffer) {
        this._glCheckError('isRenderbuffer');
        this._checkArgs('isRenderbuffer', arguments);
        var value = renderbuffer ? renderbuffer.native : null;
        return this.context.isRenderbuffer(value);
    };
    TNSWebGLRenderingContext.prototype.isShader = function (shader) {
        this._glCheckError('isShader');
        this._checkArgs('isShader', arguments);
        var value = shader ? shader.native : null;
        return this.context.isShader(value);
    };
    TNSWebGLRenderingContext.prototype.isTexture = function (texture) {
        this._glCheckError('isTexture');
        this._checkArgs('isTexture', arguments);
        var value = texture ? texture.native : null;
        return this.context.isTexture(value);
    };
    TNSWebGLRenderingContext.prototype.lineWidth = function (width) {
        this._glCheckError('lineWidth');
        this._checkArgs('lineWidth', arguments);
        this.context.lineWidth(width);
    };
    TNSWebGLRenderingContext.prototype.linkProgram = function (program) {
        this._glCheckError('linkProgram');
        this._checkArgs('linkProgram', arguments);
        var value = program ? program.native : null;
        this.context.linkProgram(value);
    };
    TNSWebGLRenderingContext.prototype.pixelStorei = function (pname, param) {
        this._glCheckError('pixelStorei');
        this._checkArgs('pixelStorei', arguments);
        if (pname === this.UNPACK_FLIP_Y_WEBGL || pname === this.UNPACK_PREMULTIPLY_ALPHA_WEBGL) {
            this.context.pixelStorei(pname, java.lang.Boolean.valueOf(param));
        }
        else if (pname === this.PACK_ALIGNMENT || pname === this.UNPACK_ALIGNMENT || pname === this.UNPACK_COLORSPACE_CONVERSION_WEBGL) {
            if (pname === this.UNPACK_COLORSPACE_CONVERSION_WEBGL) {
                param = 0x9244;
            }
            else if (pname === this.PACK_ALIGNMENT || pname === this.UNPACK_ALIGNMENT) {
                param = 4;
            }
            this.context.pixelStorei(pname, java.lang.Integer.valueOf(param));
        }
        else {
            this.context.pixelStorei(pname, param);
        }
    };
    TNSWebGLRenderingContext.prototype.polygonOffset = function (factor, units) {
        this._glCheckError('polygonOffset');
        this._checkArgs('polygonOffset', arguments);
        this.context.polygonOffset(factor, units);
    };
    TNSWebGLRenderingContext.prototype.readPixels = function (x, y, width, height, format, type, pixels) {
        this._glCheckError('readPixels');
        this._checkArgs('readPixels', arguments);
        if (pixels && pixels.buffer instanceof ArrayBuffer) {
            if (pixels instanceof Uint8Array) {
                this.context.readPixels(x, y, width, height, format, type, this.toNativeArray(pixels, 'byte'));
            }
            else if (pixels instanceof Uint16Array || pixels instanceof Int16Array) {
                this.context.readPixels(x, y, width, height, format, type, this.toNativeArray(pixels, 'short'));
            }
            else if (pixels instanceof Uint32Array) {
                this.context.readPixels(x, y, width, height, format, type, this.toNativeArray(pixels, 'int'));
            }
            else if (pixels instanceof Float32Array) {
                this.context.readPixels(x, y, width, height, format, type, this.toNativeArray(pixels, 'float'));
            }
        }
        else if (pixels instanceof ArrayBuffer) {
            this.context.readPixels(x, y, width, height, format, type, this.toNativeArray(new Uint8Array(pixels.slice(0)), 'byte'));
        }
    };
    TNSWebGLRenderingContext.prototype.renderbufferStorage = function (target, internalFormat, width, height) {
        this._glCheckError('renderbufferStorage');
        this._checkArgs('renderbufferStorage', arguments);
        if (internalFormat === this.DEPTH_STENCIL) {
            internalFormat = 0x88F0;
        }
        this.context.renderbufferStorage(target, internalFormat, width, height);
    };
    TNSWebGLRenderingContext.prototype.sampleCoverage = function (value, invert) {
        this._glCheckError('sampleCoverage');
        this._checkArgs('sampleCoverage', arguments);
        this.context.sampleCoverage(value, invert);
    };
    TNSWebGLRenderingContext.prototype.scissor = function (x, y, width, height) {
        this._glCheckError('scissor');
        this._checkArgs('scissor', arguments);
        this.context.scissor(x, y, width, height);
    };
    TNSWebGLRenderingContext.prototype.shaderSource = function (shader, source) {
        this._glCheckError('shaderSource');
        this._checkArgs('shaderSource', arguments);
        var value = shader ? shader.native : null;
        this.context.shaderSource(value, source ? source : '');
    };
    TNSWebGLRenderingContext.prototype.stencilFuncSeparate = function (face, func, ref, mask) {
        this._glCheckError('stencilFuncSeparate');
        this._checkArgs('stencilFuncSeparate', arguments);
        this.context.stencilFuncSeparate(face, func, ref, mask);
    };
    TNSWebGLRenderingContext.prototype.stencilFunc = function (func, ref, mask) {
        this._glCheckError('stencilFunc');
        this._checkArgs('stencilFunc', arguments);
        this.context.stencilFunc(func, ref, mask);
    };
    TNSWebGLRenderingContext.prototype.stencilMaskSeparate = function (face, mask) {
        this._glCheckError('stencilMaskSeparate');
        this._checkArgs('stencilMaskSeparate', arguments);
        this.context.stencilMaskSeparate(face, mask);
    };
    TNSWebGLRenderingContext.prototype.stencilMask = function (mask) {
        this._glCheckError('stencilMask');
        this._checkArgs('stencilMask', arguments);
        this.context.stencilMask(mask);
    };
    TNSWebGLRenderingContext.prototype.stencilOpSeparate = function (face, fail, zfail, zpass) {
        this._glCheckError('stencilOpSeparate');
        this._checkArgs('stencilOpSeparate', arguments);
        this.context.stencilOpSeparate(face, fail, zfail, zpass);
    };
    TNSWebGLRenderingContext.prototype.stencilOp = function (fail, zfail, zpass) {
        this._glCheckError('stencilOp');
        this._checkArgs('stencilOp', arguments);
        this.context.stencilOp(fail, zfail, zpass);
    };
    TNSWebGLRenderingContext.prototype.texImage2D = function (target, level, internalformat, width, height, border, format, type, pixels) {
        this._glCheckError('texImage2D');
        this._checkArgs('texImage2D', arguments);
        if (arguments.length === 9) {
            if (pixels && pixels.buffer instanceof ArrayBuffer) {
                if (pixels instanceof Uint8Array) {
                    this.context.texImage2D(target, level, internalformat, width, height, border, format, type, this.toNativeArray(pixels, 'byte'));
                }
                else if (pixels instanceof Uint16Array) {
                    this.context.texImage2D(target, level, internalformat, width, height, border, format, type, this.toNativeArray(pixels, 'short'));
                }
                else if (pixels instanceof Uint32Array) {
                    this.context.texImage2D(target, level, internalformat, width, height, border, format, type, this.toNativeArray(pixels, 'int'));
                }
                else if (pixels instanceof Float32Array) {
                    this.context.texImage2D(target, level, internalformat, width, height, border, format, type, this.toNativeArray(pixels, 'float'));
                }
            }
            else if (pixels instanceof ArrayBuffer) {
                this.context.texImage2D(target, level, internalformat, width, height, border, format, type, this.toNativeArray(new Uint8Array(pixels.slice(0)), 'float'));
            }
            else {
                this.context.texImage2D(target, level, internalformat, width, height, border, format, type, pixels);
            }
        }
        else if (arguments.length === 6) {
            if (border instanceof TNSImageAsset_1.TNSImageAsset) {
                this.context.texImage2D(target, level, internalformat, width, height, border.native);
            }
            else if (border instanceof android.graphics.Bitmap) {
                this.context.texImage2D(target, level, internalformat, width, height, border);
            }
            else if (border instanceof image_source_1.ImageSource) {
                this.context.texImage2D(target, level, internalformat, width, height, border.android);
            }
            else if (border &&
                typeof border.tagName === 'string' &&
                border.tagName === 'IMG') {
                if (border._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                    this.context.texImage2D(target, level, internalformat, width, height, border._asset.native);
                }
                else if (border._imageSource instanceof image_source_1.ImageSource) {
                    this.context.texImage2D(target, level, internalformat, width, height, border._imageSource.android);
                }
                else if (border._image instanceof android.graphics.Bitmap) {
                    this.context.texImage2D(target, level, internalformat, width, height, border._image);
                }
                else if (typeof border.src === 'string') {
                    this.context.texImage2D(target, level, internalformat, width, height, image_source_1.fromFile(border.src).android);
                }
            }
        }
    };
    TNSWebGLRenderingContext.prototype.texParameterf = function (target, pname, param) {
        this._glCheckError('texParameterf');
        this._checkArgs('texParameterf', arguments);
        this.context.texParameterf(target, pname, param);
    };
    TNSWebGLRenderingContext.prototype.texParameteri = function (target, pname, param) {
        this._glCheckError('texParameteri');
        this._checkArgs('texParameteri', arguments);
        this.context.texParameteri(target, pname, param);
    };
    TNSWebGLRenderingContext.prototype.texSubImage2D = function (target, level, xoffset, yoffset, width, height, format, type, pixels) {
        this._glCheckError('texSubImage2D');
        this._checkArgs('texSubImage2D', arguments);
        if (arguments.length === 9) {
            if (pixels && pixels.buffer) {
                if (pixels instanceof Uint8Array) {
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, this.toNativeArray(pixels, 'byte'));
                }
                else if (pixels instanceof Uint16Array) {
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, this.toNativeArray(pixels, 'short'));
                }
                else if (pixels instanceof Uint32Array) {
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, this.toNativeArray(pixels, 'int'));
                }
                else if (pixels instanceof Float32Array) {
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, this.toNativeArray(pixels, 'float'));
                }
            }
            else if (pixels instanceof ArrayBuffer) {
                this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, this.toNativeArray(new Uint8Array(pixels.slice(0)), 'byte'));
            }
        }
        else if (arguments.length === 7) {
            if (format instanceof android.graphics.Bitmap) {
                this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format);
            }
            else if (format instanceof image_source_1.ImageSource) {
                this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format.android);
            }
            else if (format instanceof TNSImageAsset_1.TNSImageAsset) {
                this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format.native);
            }
            else if (format &&
                typeof format.tagName === 'string' &&
                format.tagName === 'IMG') {
                if (format._imageSource instanceof image_source_1.ImageSource) {
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format._imageSource.android);
                }
                else if (format._image instanceof android.graphics.Bitmap) {
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format._image);
                }
                else if (format._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format._asset.native);
                }
                else if (typeof format.src === 'string') {
                    var result = image_source_1.fromFile(format.src);
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, result ? result.android : null);
                }
            }
        }
    };
    TNSWebGLRenderingContext.prototype.uniform1f = function (location, v0) {
        this._glCheckError('uniform1f');
        this._checkArgs('uniform1f', arguments);
        this.context.uniform1f(location.native, v0);
    };
    TNSWebGLRenderingContext.prototype.uniform1iv = function (location, value) {
        this._glCheckError('uniform1iv');
        this._checkArgs('uniform1iv', arguments);
        value = this.toNativeArray(value, 'int');
        this.context.uniform1iv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform1fv = function (location, value) {
        this._glCheckError('uniform1fv');
        this._checkArgs('uniform1fv', arguments);
        value = this.toNativeArray(value, 'float');
        this.context.uniform1fv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform1i = function (location, v0) {
        this._glCheckError('uniform1i');
        this._checkArgs('uniform1i', arguments);
        this.context.uniform1i(location.native, v0);
    };
    TNSWebGLRenderingContext.prototype.uniform2f = function (location, v0, v1) {
        this._glCheckError('uniform2f');
        this._checkArgs('uniform2f', arguments);
        this.context.uniform2f(location.native, v0, v1);
    };
    TNSWebGLRenderingContext.prototype.uniform2iv = function (location, value) {
        this._glCheckError('uniform2iv');
        this._checkArgs('uniform2iv', arguments);
        value = this.toNativeArray(value, 'int');
        this.context.uniform2iv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform2fv = function (location, value) {
        this._glCheckError('uniform2fv');
        this._checkArgs('uniform2fv', arguments);
        value = this.toNativeArray(value, 'float');
        this.context.uniform2fv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform2i = function (location, v0, v1) {
        this._glCheckError('uniform2i');
        this._checkArgs('uniform2i', arguments);
        this.context.uniform2i(location.native, v0, v1);
    };
    TNSWebGLRenderingContext.prototype.uniform3f = function (location, v0, v1, v2) {
        this._glCheckError('uniform3f');
        this._checkArgs('uniform3f', arguments);
        this.context.uniform3f(location.native, v0, v1, v2);
    };
    TNSWebGLRenderingContext.prototype.uniform3iv = function (location, value) {
        this._glCheckError('uniform3iv');
        this._checkArgs('uniform3iv', arguments);
        value = this.toNativeArray(value, 'int');
        this.context.uniform3iv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform3fv = function (location, value) {
        this._glCheckError('uniform3fv');
        this._checkArgs('uniform3fv', arguments);
        value = this.toNativeArray(value, 'float');
        this.context.uniform3fv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform3i = function (location, v0, v1, v2) {
        this._glCheckError('uniform3i');
        this._checkArgs('uniform3i', arguments);
        this.context.uniform3i(location.native, v0, v1, v2);
    };
    TNSWebGLRenderingContext.prototype.uniform4f = function (location, v0, v1, v2, v3) {
        this._glCheckError('uniform4f');
        this._checkArgs('uniform4f', arguments);
        this.context.uniform4f(location.native, v0, v1, v2, v3);
    };
    TNSWebGLRenderingContext.prototype.uniform4iv = function (location, value) {
        this._glCheckError('uniform4iv');
        this._checkArgs('uniform4iv', arguments);
        value = this.toNativeArray(value, 'int');
        this.context.uniform4iv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform4fv = function (location, value) {
        this._glCheckError('uniform4fv');
        this._checkArgs('uniform4fv', arguments);
        value = this.toNativeArray(value, 'float');
        this.context.uniform4fv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform4i = function (location, v0, v1, v2, v3) {
        this._glCheckError('uniform4i');
        this._checkArgs('uniform4i', arguments);
        this.context.uniform4i(location.native, v0, v1, v2, v3);
    };
    TNSWebGLRenderingContext.prototype.uniformMatrix2fv = function (location, transpose, value) {
        this._glCheckError('uniformMatrix2fv');
        this._checkArgs('uniformMatrix2fv', arguments);
        value = this.toNativeArray(value, 'float');
        this.context.uniformMatrix2fv(location.native, transpose, value);
    };
    TNSWebGLRenderingContext.prototype.uniformMatrix3fv = function (location, transpose, value) {
        this._glCheckError('uniformMatrix3fv');
        this._checkArgs('uniformMatrix3fv', arguments);
        value = this.toNativeArray(value, 'float');
        this.context.uniformMatrix3fv(location.native, transpose, value);
    };
    TNSWebGLRenderingContext.prototype.uniformMatrix4fv = function (location, transpose, value) {
        this._glCheckError('uniformMatrix4fv');
        this._checkArgs('uniformMatrix4fv', arguments);
        value = this.toNativeArray(value, 'float');
        this.context.uniformMatrix4fv(location.native, transpose, value);
    };
    TNSWebGLRenderingContext.prototype.useProgram = function (program) {
        this._glCheckError('useProgram');
        this._checkArgs('useProgram', arguments);
        var value = program ? program.native : null;
        this.context.useProgram(value);
    };
    TNSWebGLRenderingContext.prototype.validateProgram = function (program) {
        this._glCheckError('validateProgram');
        this._checkArgs('validateProgram', arguments);
        var value = program ? program.native : null;
        this.context.validateProgram(value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib1f = function (index, v0) {
        this._glCheckError('vertexAttrib1f');
        this._checkArgs('vertexAttrib1f', arguments);
        this.context.vertexAttrib1f(index, v0);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib1fv = function (index, value) {
        this._glCheckError('vertexAttrib1fv');
        this._checkArgs('vertexAttrib1fv', arguments);
        value = this.toNativeArray(value, 'float');
        this.context.vertexAttrib1fv(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib2f = function (index, v0, v1) {
        this._glCheckError('vertexAttrib2f');
        this._checkArgs('vertexAttrib2f', arguments);
        this.context.vertexAttrib2f(index, v0, v1);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib2fv = function (index, value) {
        this._glCheckError('vertexAttrib2fv');
        this._checkArgs('vertexAttrib2fv', arguments);
        value = this.toNativeArray(value, 'float');
        this.context.vertexAttrib2fv(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib3f = function (index, v0, v1, v2) {
        this._glCheckError('vertexAttrib3f');
        this._checkArgs('vertexAttrib3f', arguments);
        this.context.vertexAttrib3f(index, v0, v1, v2);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib3fv = function (index, value) {
        this._glCheckError('vertexAttrib3fv');
        this._checkArgs('vertexAttrib3fv', arguments);
        value = this.toNativeArray(value, 'float');
        this.context.vertexAttrib3fv(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib4f = function (index, v0, v1, v2, v3) {
        this._glCheckError('vertexAttrib4f');
        this._checkArgs('vertexAttrib4f', arguments);
        this.context.vertexAttrib4f(index, v0, v1, v2, v3);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib4fv = function (index, value) {
        this._glCheckError('vertexAttrib4fv');
        this._checkArgs('vertexAttrib4fv', arguments);
        value = this.toNativeArray(value, 'float');
        this.context.vertexAttrib4fv(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttribPointer = function (index, size, type, normalized, stride, offset) {
        this._glCheckError('vertexAttribPointer');
        this._checkArgs('vertexAttribPointer', arguments);
        this.context.vertexAttribPointer(index, size, type, normalized, stride, offset);
    };
    TNSWebGLRenderingContext.prototype.viewport = function (x, y, width, height) {
        this._glCheckError('viewport');
        this._checkArgs('viewport', arguments);
        this.context.viewport(x, y, width, height);
    };
    TNSWebGLRenderingContext.isDebug = false;
    TNSWebGLRenderingContext.filter = 'both';
    return TNSWebGLRenderingContext;
}(canvas_plugin_common_1.TNSWebGLRenderingContextBase));
exports.TNSWebGLRenderingContext = TNSWebGLRenderingContext;
//# sourceMappingURL=TNSWebGLRenderingContext.android.js.map