"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
var canvas_plugin_common_1 = require("./canvas-plugin.common");
var image_source_1 = require("tns-core-modules/image-source");
var TNSWebGLExtensions_1 = require("./TNSWebGLExtensions");
var TNSImageAsset_1 = require("./TNSImageAsset");
__export(require("./TNSWebGLExtensions"));
var TNSWebGLRenderingContext = (function (_super) {
    __extends(TNSWebGLRenderingContext, _super);
    function TNSWebGLRenderingContext(context) {
        var _this = _super.call(this, context) || this;
        _this.context = context;
        return _this;
    }
    TNSWebGLRenderingContext.prototype.getJSArray = function (value) {
        var count = value.count;
        var array = [];
        for (var i = 0; i < count; i++) {
            array.push(value.objectAtIndex(i));
        }
        return array;
    };
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "native", {
        get: function () {
            return this.context;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "drawingBufferHeight", {
        get: function () {
            return this.context.drawingBufferHeight;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "drawingBufferWidth", {
        get: function () {
            return this.context.drawingBufferWidth;
        },
        enumerable: true,
        configurable: true
    });
    TNSWebGLRenderingContext.prototype._glCheckError = function (message) {
        if (!TNSWebGLRenderingContext.isDebug) {
            return;
        }
        if (TNSWebGLRenderingContext.filter === 'both' || TNSWebGLRenderingContext.filter === 'error') {
            console.log(message, this.getError());
        }
    };
    TNSWebGLRenderingContext.prototype._checkArgs = function (message, args) {
        if (!TNSWebGLRenderingContext.isDebug) {
            return;
        }
        if (TNSWebGLRenderingContext.filter === 'both' || TNSWebGLRenderingContext.filter === 'args') {
            console.log('\/**** ', message, ' ****\/');
            console.dir(args);
            console.log('\/**** ', message, ' ****\/');
        }
    };
    TNSWebGLRenderingContext.prototype.activeTexture = function (texture) {
        this._glCheckError('activeTexture');
        this._checkArgs('activeTexture', arguments);
        this.context.activeTextureWithTexture(texture);
    };
    TNSWebGLRenderingContext.prototype.attachShader = function (program, shader) {
        var value = program ? program.native : 0;
        var value2 = shader ? shader.native : 0;
        this._glCheckError('attachShader');
        this._checkArgs('attachShader', arguments);
        this.context.attachShaderWithProgramShader(value, value2);
    };
    TNSWebGLRenderingContext.prototype.bindAttribLocation = function (program, index, name) {
        this._glCheckError('bindAttribLocation');
        this._checkArgs('bindAttribLocation', arguments);
        var value = program ? program.native : 0;
        this.context.bindAttribLocationWithProgramIndexName(value, index, name);
    };
    TNSWebGLRenderingContext.prototype.bindBuffer = function (target, buffer) {
        this._glCheckError('bindBuffer');
        this._checkArgs('bindBuffer', arguments);
        var value = buffer ? buffer.native : 0;
        this.context.bindBufferWithTargetBuffer(target, value);
    };
    TNSWebGLRenderingContext.prototype.bindFramebuffer = function (target, framebuffer) {
        this._glCheckError('bindFramebuffer');
        this._checkArgs('bindFramebuffer', arguments);
        var value = framebuffer ? framebuffer.native : 0;
        this.context.bindFramebufferWithTargetFramebuffer(target, value);
    };
    TNSWebGLRenderingContext.prototype.bindRenderbuffer = function (target, renderbuffer) {
        this._glCheckError('bindRenderbuffer');
        this._checkArgs('bindRenderbuffer', arguments);
        var value = renderbuffer ? renderbuffer.native : 0;
        this.context.bindRenderbufferWithTargetRenderbuffer(target, value);
    };
    TNSWebGLRenderingContext.prototype.bindTexture = function (target, texture) {
        this._glCheckError('bindTexture');
        this._checkArgs('bindTexture', arguments);
        var value = texture ? texture.native : 0;
        this.context.bindTextureWithTargetTexture(target, value);
    };
    TNSWebGLRenderingContext.prototype.blendColor = function (red, green, blue, alpha) {
        this._glCheckError('blendColor');
        this._checkArgs('blendColor', arguments);
        this.context.blendColorWithRedGreenBlueAlpha(red, green, blue, alpha);
    };
    TNSWebGLRenderingContext.prototype.blendEquationSeparate = function (modeRGB, modeAlpha) {
        this._glCheckError('blendEquationSeparate');
        this._checkArgs('blendEquationSeparate', arguments);
        this.context.blendEquationSeparateWithModeRGBModeAlpha(modeRGB, modeAlpha);
    };
    TNSWebGLRenderingContext.prototype.blendEquation = function (mode) {
        this._glCheckError('blendEquation');
        this._checkArgs('blendEquation', arguments);
        this.context.blendEquationWithMode(mode);
    };
    TNSWebGLRenderingContext.prototype.blendFuncSeparate = function (srcRGB, dstRGB, srcAlpha, dstAlpha) {
        if (srcRGB === void 0) { srcRGB = this.ONE; }
        if (dstRGB === void 0) { dstRGB = this.ZERO; }
        if (srcAlpha === void 0) { srcAlpha = this.ONE; }
        if (dstAlpha === void 0) { dstAlpha = this.ZERO; }
        this._glCheckError('blendFuncSeparate');
        this._checkArgs('blendFuncSeparate', arguments);
        this.context.blendFuncSeparateWithSrcRGBDstRGBSrcAlphaDstAlpha(srcRGB, dstRGB, srcAlpha, dstAlpha);
    };
    TNSWebGLRenderingContext.prototype.blendFunc = function (sfactor, dfactor) {
        if (sfactor === void 0) { sfactor = this.ONE; }
        if (dfactor === void 0) { dfactor = this.ZERO; }
        this._glCheckError('blendFunc');
        this._checkArgs('blendFunc', arguments);
        this.context.blendFuncWithSfactorDfactor(sfactor, dfactor);
    };
    TNSWebGLRenderingContext.prototype.bufferData = function (target, srcData, usage) {
        this._glCheckError('bufferData');
        this._checkArgs('bufferData', arguments);
        if (typeof srcData === 'number') {
            this.context.bufferDataWithTargetSizeUsage(target, srcData, usage);
        }
        else if (srcData instanceof ArrayBuffer) {
            this.context.bufferDataWithTargetByteArrayUsage(target, new Uint8Array(srcData.slice(0)), usage);
        }
        else if (srcData && srcData.buffer instanceof ArrayBuffer) {
            if (srcData instanceof Float32Array || srcData instanceof Float64Array) {
                this.context.bufferDataWithTargetFloatArrayUsage(target, srcData, usage);
            }
            else if (srcData instanceof Uint32Array || srcData instanceof Int32Array) {
                this.context.bufferDataWithTargetIntArrayUsage(target, srcData, usage);
            }
            else if (srcData instanceof Uint16Array || srcData instanceof Int16Array) {
                this.context.bufferDataWithTargetShortArrayUsage(target, srcData, usage);
            }
            else if (srcData instanceof Uint8Array) {
                this.context.bufferDataWithTargetByteArrayUsage(target, srcData, usage);
            }
        }
        else {
            this.context.bufferDataWithTargetSrcDataUsage(target, srcData, usage);
        }
    };
    TNSWebGLRenderingContext.prototype.bufferSubData = function (target, offset, srcData) {
        this._glCheckError('bufferSubData');
        this._checkArgs('bufferSubData', arguments);
        if (srcData instanceof ArrayBuffer) {
            this.context.bufferSubDataWithTargetOffsetByteArray(target, offset, new Uint8Array(srcData.slice(0)));
        }
        else if (srcData && srcData.buffer instanceof ArrayBuffer) {
            if (srcData instanceof Float32Array || srcData instanceof Float64Array) {
                this.context.bufferSubDataWithTargetOffsetFloatArray(target, offset, srcData);
            }
            else if (srcData instanceof Uint32Array || srcData instanceof Int32Array) {
                this.context.bufferSubDataWithTargetOffsetIntArray(target, offset, srcData);
            }
            else if (srcData instanceof Uint16Array || srcData instanceof Int16Array) {
                this.context.bufferSubDataWithTargetOffsetShortArray(target, offset, srcData);
            }
            else if (srcData instanceof Uint8Array) {
                this.context.bufferSubDataWithTargetOffsetByteArray(target, offset, srcData);
            }
        }
    };
    TNSWebGLRenderingContext.prototype.checkFramebufferStatus = function (target) {
        this._glCheckError('checkFramebufferStatus');
        this._checkArgs('checkFramebufferStatus', arguments);
        return this.context.checkFramebufferStatusWithTarget(target);
    };
    TNSWebGLRenderingContext.prototype.clearColor = function (red, green, blue, alpha) {
        this._glCheckError('clearColor');
        this._checkArgs('clearColor', arguments);
        this.context.clearColorWithRedGreenBlueAlpha(red, green, blue, alpha);
    };
    TNSWebGLRenderingContext.prototype.clearDepth = function (depth) {
        this._glCheckError('clearDepth');
        this._checkArgs('clearDepth', arguments);
        this.context.clearDepthWithDepth(depth);
    };
    TNSWebGLRenderingContext.prototype.clearStencil = function (stencil) {
        this._glCheckError('clearStencil');
        this._checkArgs('clearStencil', arguments);
        this.context.clearStencilWithStencil(stencil);
    };
    TNSWebGLRenderingContext.prototype.clear = function (mask) {
        this._glCheckError('clear');
        this._checkArgs('clear', arguments);
        this.context.clearWithMask(mask);
        this._glCheckError('after clear');
    };
    TNSWebGLRenderingContext.prototype.colorMask = function (red, green, blue, alpha) {
        this._glCheckError('colorMask');
        this._checkArgs('colorMask', arguments);
        this.context.colorMaskWithRedGreenBlueAlpha(red, green, blue, alpha);
    };
    TNSWebGLRenderingContext.prototype.commit = function () {
        this.context.commit();
    };
    TNSWebGLRenderingContext.prototype.compileShader = function (shader) {
        this._glCheckError('compileShader');
        this._checkArgs('compileShader', arguments);
        var value = shader ? shader.native : 0;
        this.context.compileShaderWithShader(value);
    };
    TNSWebGLRenderingContext.prototype.compressedTexImage2D = function (target, level, internalformat, width, height, border, pixels) {
        this._glCheckError('compressedTexImage2D');
        this._checkArgs('compressedTexImage2D', arguments);
        if (pixels && pixels.buffer instanceof ArrayBuffer) {
            if (pixels instanceof Float32Array || pixels instanceof Float64Array) {
                this.context.compressedTexImage2DWithTargetLevelInternalformatWidthHeightBorderFloatArray(target, level, internalformat, width, height, border, pixels);
            }
            else if (pixels instanceof Uint32Array || pixels instanceof Int32Array) {
                this.context.compressedTexImage2DWithTargetLevelInternalformatWidthHeightBorderIntArray(target, level, internalformat, width, height, border, pixels);
            }
            else if (pixels instanceof Uint16Array || pixels instanceof Int16Array) {
                this.context.compressedTexImage2DWithTargetLevelInternalformatWidthHeightBorderShortArray(target, level, internalformat, width, height, border, pixels);
            }
            else if (pixels instanceof Uint8Array) {
                this.context.compressedTexImage2DWithTargetLevelInternalformatWidthHeightBorderByteArray(target, level, internalformat, width, height, border, pixels);
            }
        }
        else if (pixels instanceof ArrayBuffer) {
            this.context.compressedTexImage2DWithTargetLevelInternalformatWidthHeightBorderByteArray(target, level, internalformat, width, height, border, new Uint8Array(pixels.slice(0)));
        }
        else {
            this.context.compressedTexImage2DWithTargetLevelInternalformatWidthHeightBorderPixels(target, level, internalformat, width, height, border, pixels);
        }
    };
    TNSWebGLRenderingContext.prototype.compressedTexSubImage2D = function (target, level, xoffset, yoffset, width, height, format, pixels) {
        this._glCheckError('compressedTexSubImage2D');
        this._checkArgs('compressedTexSubImage2D', arguments);
        if (pixels && pixels.buffer instanceof ArrayBuffer) {
            if (pixels instanceof Float32Array || pixels instanceof Float64Array) {
                this.context.compressedTexSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatFloatArray(target, level, xoffset, yoffset, width, height, format, pixels);
            }
            else if (pixels instanceof Uint32Array || pixels instanceof Int32Array) {
                this.context.compressedTexSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatIntArray(target, level, xoffset, yoffset, width, height, format, pixels);
            }
            else if (pixels instanceof Uint16Array || pixels instanceof Int16Array) {
                this.context.compressedTexSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatShortArray(target, level, xoffset, yoffset, width, height, format, pixels);
            }
            else if (pixels instanceof Uint8Array) {
                this.context.compressedTexSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatByteArray(target, level, xoffset, yoffset, width, height, format, pixels);
            }
        }
        else if (pixels instanceof ArrayBuffer) {
            this.context.compressedTexSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatByteArray(target, level, xoffset, yoffset, width, height, format, new Uint8Array(pixels.slice(0)));
        }
    };
    TNSWebGLRenderingContext.prototype.copyTexImage2D = function (target, level, internalformat, x, y, width, height, border) {
        this._glCheckError('copyTexImage2D');
        this._checkArgs('copyTexImage2D', arguments);
        this.context.copyTexImage2DWithTargetLevelInternalformatXYWidthHeightBorder(target, level, internalformat, x, y, width, height, border);
    };
    TNSWebGLRenderingContext.prototype.copyTexSubImage2D = function (target, level, xoffset, yoffset, x, y, width, height) {
        this._glCheckError('copyTexSubImage2D');
        this._checkArgs('copyTexSubImage2D', arguments);
        this.context.copyTexSubImage2DWithTargetLevelXoffsetYoffsetXYWidthHeight(target, level, xoffset, yoffset, x, y, width, height);
    };
    TNSWebGLRenderingContext.prototype.createBuffer = function () {
        this._glCheckError('createBuffer');
        this._checkArgs('createBuffer', arguments);
        var id = this.context.createBuffer();
        return new canvas_plugin_common_1.WebGLBuffer(id);
    };
    TNSWebGLRenderingContext.prototype.createFramebuffer = function () {
        this._glCheckError('createFramebuffer');
        this._checkArgs('createFramebuffer', arguments);
        return new canvas_plugin_common_1.WebGLFramebuffer(this.context.createFramebuffer());
    };
    TNSWebGLRenderingContext.prototype.createProgram = function () {
        this._glCheckError('createProgram');
        this._checkArgs('createProgram', arguments);
        return new canvas_plugin_common_1.WebGLProgram(this.context.createProgram());
    };
    TNSWebGLRenderingContext.prototype.createRenderbuffer = function () {
        this._glCheckError('bindBuffer');
        this._checkArgs('bindBuffer', arguments);
        return new canvas_plugin_common_1.WebGLRenderbuffer(this.context.createRenderbuffer());
    };
    TNSWebGLRenderingContext.prototype.createShader = function (type) {
        this._glCheckError('createRenderbuffer');
        this._checkArgs('createRenderbuffer', arguments);
        return new canvas_plugin_common_1.WebGLShader(this.context.createShaderWithType(type));
    };
    TNSWebGLRenderingContext.prototype.createTexture = function () {
        this._glCheckError('createTexture');
        this._checkArgs('createTexture', arguments);
        var id = this.context.createTexture();
        return new canvas_plugin_common_1.WebGLTexture(id);
    };
    TNSWebGLRenderingContext.prototype.cullFace = function (mode) {
        this._glCheckError('cullFace');
        this._checkArgs('cullFace', arguments);
        this.context.cullFaceWithMode(mode);
    };
    TNSWebGLRenderingContext.prototype.deleteBuffer = function (buffer) {
        this._glCheckError('deleteBuffer');
        this._checkArgs('deleteBuffer', arguments);
        var value = buffer ? buffer.native : 0;
        this.context.deleteBufferWithBuffer(value);
    };
    TNSWebGLRenderingContext.prototype.deleteFramebuffer = function (frameBuffer) {
        this._glCheckError('deleteFramebuffer');
        this._checkArgs('deleteFramebuffer', arguments);
        var value = frameBuffer ? frameBuffer.native : 0;
        this.context.deleteFramebufferWithFrameBuffer(value);
    };
    TNSWebGLRenderingContext.prototype.deleteProgram = function (program) {
        this._glCheckError('deleteProgram');
        this._checkArgs('deleteProgram', arguments);
        var value = program ? program.native : 0;
        this.context.deleteProgramWithProgram(value);
    };
    TNSWebGLRenderingContext.prototype.deleteRenderbuffer = function (renderBuffer) {
        this._glCheckError('deleteRenderbuffer');
        this._checkArgs('deleteRenderbuffer', arguments);
        var value = renderBuffer ? renderBuffer.native : 0;
        this.context.deleteRenderbufferWithRenderbuffer(value);
    };
    TNSWebGLRenderingContext.prototype.deleteShader = function (shader) {
        this._glCheckError('deleteShader');
        this._checkArgs('deleteShader', arguments);
        var value = shader ? shader.native : 0;
        this.context.deleteShaderWithShader(value);
    };
    TNSWebGLRenderingContext.prototype.deleteTexture = function (texture) {
        this._glCheckError('deleteTexture');
        this._checkArgs('deleteTexture', arguments);
        var value = texture ? texture.native : 0;
        this.context.deleteTextureWithTexture(value);
    };
    TNSWebGLRenderingContext.prototype.depthFunc = function (func) {
        this._glCheckError('depthFunc');
        this._checkArgs('depthFunc', arguments);
        this.context.depthFuncWithFn(func);
    };
    TNSWebGLRenderingContext.prototype.depthMask = function (flag) {
        this._glCheckError('depthMask');
        this._checkArgs('depthMask', arguments);
        this.context.depthMaskWithFlag(flag);
    };
    TNSWebGLRenderingContext.prototype.depthRange = function (zNear, zFar) {
        this._glCheckError('depthRange');
        this._checkArgs('depthRange', arguments);
        this.context.depthRangeWithZNearZFar(zNear, zFar);
    };
    TNSWebGLRenderingContext.prototype.detachShader = function (program, shader) {
        this._glCheckError('detachShader');
        this._checkArgs('detachShader', arguments);
        var value = program ? program.native : 0;
        var value2 = shader ? shader.native : 0;
        this.context.detachShaderWithProgramShader(value, value2);
    };
    TNSWebGLRenderingContext.prototype.disableVertexAttribArray = function (index) {
        this._checkArgs('disableVertexAttribArray', arguments);
        this._glCheckError('disableVertexAttribArray');
        this.context.disableVertexAttribArrayWithIndex(index);
    };
    TNSWebGLRenderingContext.prototype.disable = function (cap) {
        this._glCheckError('disable');
        this._checkArgs('disable', arguments);
        this.context.disableWithCap(cap);
    };
    TNSWebGLRenderingContext.prototype.drawArrays = function (mode, first, count) {
        this._glCheckError('drawArrays');
        this._checkArgs('drawArrays', arguments);
        this.context.drawArraysWithModeFirstCount(mode, first, count);
    };
    TNSWebGLRenderingContext.prototype.drawElements = function (mode, count, type, offset) {
        this._glCheckError('drawElements');
        this._checkArgs('drawElements', arguments);
        this.context.drawElementsWithModeCountTypeOffset(mode, count, type, offset);
    };
    TNSWebGLRenderingContext.prototype.enableVertexAttribArray = function (index) {
        this._glCheckError('enableVertexAttribArray');
        this._checkArgs('enableVertexAttribArray', arguments);
        this.context.enableVertexAttribArrayWithIndex(index);
    };
    TNSWebGLRenderingContext.prototype.enable = function (cap) {
        this._glCheckError('enable');
        this._checkArgs('enable', arguments);
        this.context.enableWithCap(cap);
    };
    TNSWebGLRenderingContext.prototype.finish = function () {
        this._glCheckError('finish');
        this._checkArgs('finish', arguments);
        this.context.finish();
    };
    TNSWebGLRenderingContext.prototype.flush = function () {
        this._glCheckError('flush');
        this._checkArgs('flush', arguments);
        this.context.flush();
    };
    TNSWebGLRenderingContext.prototype.framebufferRenderbuffer = function (target, attachment, renderbuffertarget, renderbuffer) {
        this._glCheckError('framebufferRenderbuffer');
        this._checkArgs('framebufferRenderbuffer', arguments);
        var value = renderbuffer ? renderbuffer.native : 0;
        this.context.framebufferRenderbufferWithTargetAttachmentRenderbuffertargetRenderbuffer(target, attachment, renderbuffertarget, value);
    };
    TNSWebGLRenderingContext.prototype.framebufferTexture2D = function (target, attachment, textarget, texture, level) {
        this._glCheckError('framebufferTexture2D');
        this._checkArgs('framebufferTexture2D', arguments);
        var value = texture ? texture.native : 0;
        this.context.framebufferTexture2DWithTargetAttachmentTextargetTextureLevel(target, attachment, textarget, value, level);
    };
    TNSWebGLRenderingContext.prototype.frontFace = function (mode) {
        this._glCheckError('frontFace');
        this._checkArgs('frontFace', arguments);
        this.context.frontFaceWithMode(mode);
    };
    TNSWebGLRenderingContext.prototype.generateMipmap = function (target) {
        this._glCheckError('generateMipmap');
        this._checkArgs('generateMipmap', arguments);
        this.context.generateMipmapWithTarget(target);
    };
    TNSWebGLRenderingContext.prototype.getActiveAttrib = function (program, index) {
        this._glCheckError('getActiveAttrib');
        this._checkArgs('getActiveAttrib', arguments);
        var value = program ? program.native : 0;
        var attrib = this.context.getActiveAttribWithProgramIndex(value, index);
        return new canvas_plugin_common_1.WebGLActiveInfo(attrib.name, attrib.size, attrib.type);
    };
    TNSWebGLRenderingContext.prototype.getActiveUniform = function (program, index) {
        this._glCheckError('getActiveUniform');
        this._checkArgs('getActiveUniform', arguments);
        var value = program ? program.native : 0;
        var uniform = this.context.getActiveUniformWithProgramIndex(value, index);
        return new canvas_plugin_common_1.WebGLActiveInfo(uniform.name, uniform.size, uniform.type);
    };
    TNSWebGLRenderingContext.prototype.getAttachedShaders = function (program) {
        this._glCheckError('getAttachedShaders');
        this._checkArgs('getAttachedShaders', arguments);
        var value = program ? program.native : 0;
        var shaders = this.context.getAttachedShadersWithProgram(value);
        var length = shaders.count;
        var attachedShaders = [];
        for (var i = 0; i < length; i++) {
            attachedShaders.push(new canvas_plugin_common_1.WebGLShader(shaders.objectAtIndex(i)));
        }
        return attachedShaders;
    };
    TNSWebGLRenderingContext.prototype.getAttribLocation = function (program, name) {
        this._glCheckError('getAttribLocation');
        this._checkArgs('getAttribLocation', arguments);
        var value = program ? program.native : 0;
        return this.context.getAttribLocationWithProgramName(value, name);
    };
    TNSWebGLRenderingContext.prototype.getBufferParameter = function (target, pname) {
        this._glCheckError('getBufferParameter');
        this._checkArgs('getBufferParameter', arguments);
        return this.context.getBufferParameterWithTargetPname(target, pname);
    };
    TNSWebGLRenderingContext.prototype.getContextAttributes = function () {
        this._glCheckError('getContextAttributes');
        this._checkArgs('getContextAttributes', arguments);
        var attributes = this.context.getContextAttributes();
        var keys = attributes.allKeys;
        var length = keys.count;
        var contextAttributes = {};
        for (var i = 0; i < length; i++) {
            var key = keys.objectAtIndex(i);
            contextAttributes[key] = attributes.objectForKey(key);
        }
        return contextAttributes;
    };
    TNSWebGLRenderingContext.prototype.getError = function () {
        return this.context.getError();
    };
    TNSWebGLRenderingContext.prototype.getExtension = function (name) {
        this._checkArgs('activattachShadereTexture', arguments);
        this._glCheckError('activattachShadereTexture');
        var ext = this.context.getExtensionWithName(name);
        if (ext instanceof Canvas_ANGLE_instanced_arrays) {
            return new TNSWebGLExtensions_1.ANGLE_instanced_arrays(ext);
        }
        else if (ext instanceof Canvas_EXT_blend_minmax) {
            return new TNSWebGLExtensions_1.EXT_blend_minmax(ext);
        }
        else if (ext instanceof Canvas_EXT_color_buffer_float) {
            return new TNSWebGLExtensions_1.EXT_color_buffer_float(ext);
        }
        else if (ext instanceof Canvas_EXT_color_buffer_half_float) {
            return new TNSWebGLExtensions_1.EXT_color_buffer_half_float(ext);
        }
        else if (ext instanceof Canvas_EXT_sRGB) {
            return new TNSWebGLExtensions_1.EXT_sRGB(ext);
        }
        else if (ext instanceof Canvas_EXT_shader_texture_lod) {
            return new TNSWebGLExtensions_1.EXT_shader_texture_lod(ext);
        }
        else if (ext instanceof Canvas_EXT_texture_filter_anisotropic) {
            return new TNSWebGLExtensions_1.EXT_texture_filter_anisotropic(ext);
        }
        else if (ext instanceof Canvas_OES_element_index_uint) {
            return new TNSWebGLExtensions_1.OES_element_index_uint(ext);
        }
        else if (ext instanceof Canvas_OES_fbo_render_mipmap) {
            return new TNSWebGLExtensions_1.OES_fbo_render_mipmap(ext);
        }
        else if (ext instanceof Canvas_OES_standard_derivatives) {
            return new TNSWebGLExtensions_1.OES_standard_derivatives(ext);
        }
        else if (ext instanceof Canvas_OES_texture_float) {
            return new TNSWebGLExtensions_1.OES_texture_float(ext);
        }
        else if (ext instanceof Canvas_OES_texture_float_linear) {
            return new TNSWebGLExtensions_1.OES_texture_float_linear(ext);
        }
        else if (ext instanceof Canvas_OES_texture_half_float) {
            return new TNSWebGLExtensions_1.OES_texture_half_float(ext);
        }
        else if (ext instanceof Canvas_OES_texture_half_float_linear) {
            return new TNSWebGLExtensions_1.OES_texture_half_float_linear(ext);
        }
        else if (ext instanceof Canvas_OES_vertex_array_object) {
            return new TNSWebGLExtensions_1.OES_vertex_array_object(ext);
        }
        else if (ext instanceof Canvas_WEBGL_color_buffer_float) {
            return new TNSWebGLExtensions_1.WEBGL_color_buffer_float(ext);
        }
        else if (ext instanceof Canvas_WEBGL_compressed_texture_etc) {
            return new TNSWebGLExtensions_1.WEBGL_compressed_texture_etc(ext);
        }
        else if (ext instanceof Canvas_WEBGL_compressed_texture_etc1) {
            return new TNSWebGLExtensions_1.WEBGL_compressed_texture_etc1(ext);
        }
        else if (ext instanceof Canvas_WEBGL_compressed_texture_pvrtc) {
            return new TNSWebGLExtensions_1.WEBGL_compressed_texture_pvrtc(ext);
        }
        else if (ext instanceof Canvas_WEBGL_depth_texture) {
            return new TNSWebGLExtensions_1.WEBGL_depth_texture(ext);
        }
        else if (ext instanceof Canvas_WEBGL_lose_context) {
            return new TNSWebGLExtensions_1.WEBGL_lose_context(ext);
        }
        else if (ext instanceof Canvas_WEBGL_draw_buffers) {
            return new TNSWebGLExtensions_1.WEBGL_draw_buffers(ext);
        }
        return null;
    };
    TNSWebGLRenderingContext.prototype.getFramebufferAttachmentParameter = function (target, attachment, pname) {
        this._glCheckError('getFramebufferAttachmentParameter');
        this._checkArgs('getFramebufferAttachmentParameter', arguments);
        var param = this.context.getFramebufferAttachmentParameterWithTargetAttachmentPname(target, attachment, pname);
        if (param.isRenderbuffer) {
            return new canvas_plugin_common_1.WebGLRenderbuffer(param.value);
        }
        else if (param.isTexture) {
            return new canvas_plugin_common_1.WebGLTexture(param.value);
        }
        return param.value;
    };
    TNSWebGLRenderingContext.prototype.getParameter = function (pname) {
        this._glCheckError('getParameter');
        this._checkArgs('getParameter', arguments);
        var value = this.context.getParameterWithPname(pname);
        switch (pname) {
            case this.COLOR_WRITEMASK:
            case this.COLOR_CLEAR_VALUE:
            case this.BLEND_COLOR:
            case this.ALIASED_LINE_WIDTH_RANGE:
            case this.ALIASED_POINT_SIZE_RANGE:
            case this.DEPTH_RANGE:
                if (value instanceof NSArray) {
                    var count = value.count;
                    var array = [];
                    for (var i = 0; i < count; i++) {
                        array.push(value.objectAtIndex(i));
                    }
                    return array;
                }
                return value;
            case this.ARRAY_BUFFER_BINDING:
            case this.ELEMENT_ARRAY_BUFFER_BINDING:
                return new canvas_plugin_common_1.WebGLBuffer(value);
            case this.CURRENT_PROGRAM:
                return new canvas_plugin_common_1.WebGLProgram(value);
            case this.COMPRESSED_TEXTURE_FORMATS:
                var size = value.count;
                var result = [];
                for (var i = 0; i < size; i++) {
                    result.push(value.objectAtIndex(i));
                }
                return new Uint32Array(result);
            case this.RENDERBUFFER_BINDING:
                return new canvas_plugin_common_1.WebGLRenderbuffer(value);
            case this.FRAMEBUFFER_BINDING:
                if (value) {
                    return new canvas_plugin_common_1.WebGLFramebuffer(value);
                }
                return null;
            case this.VIEWPORT:
            case this.SCISSOR_BOX:
            case this.MAX_VIEWPORT_DIMS:
                var len = value.count;
                var arr = [];
                for (var i = 0; i < len; i++) {
                    arr.push(value.objectAtIndex(i));
                }
                return new Int32Array(arr);
            case this.TEXTURE_BINDING_CUBE_MAP:
            case this.TEXTURE_BINDING_2D:
                if (value) {
                    return new canvas_plugin_common_1.WebGLTexture(value);
                }
                return null;
            default:
                return value;
        }
    };
    TNSWebGLRenderingContext.prototype.getProgramInfoLog = function (program) {
        this._glCheckError('getProgramInfoLog');
        this._checkArgs('getProgramInfoLog', arguments);
        var value = program ? program.native : 0;
        return this.context.getProgramInfoLogWithProgram(value);
    };
    TNSWebGLRenderingContext.prototype.getProgramParameter = function (program, pname) {
        this._glCheckError('getProgramParameter');
        this._checkArgs('getProgramParameter', arguments);
        var value = program ? program.native : 0;
        return this.context.getProgramParameterWithProgramPname(value, pname);
    };
    TNSWebGLRenderingContext.prototype.getRenderbufferParameter = function (target, pname) {
        this._glCheckError('getRenderbufferParameter');
        this._checkArgs('getRenderbufferParameter', arguments);
        return this.context.getBufferParameterWithTargetPname(target, pname);
    };
    TNSWebGLRenderingContext.prototype.getShaderInfoLog = function (shader) {
        this._glCheckError('getShaderInfoLog');
        this._checkArgs('getShaderInfoLog', arguments);
        var value = shader ? shader.native : 0;
        return this.context.getShaderInfoLogWithShader(value);
    };
    TNSWebGLRenderingContext.prototype.getShaderParameter = function (shader, pname) {
        this._glCheckError('getShaderParameter');
        this._checkArgs('getShaderParameter', arguments);
        var value = shader ? shader.native : 0;
        return this.context.getShaderParameterWithShaderPname(value, pname);
    };
    TNSWebGLRenderingContext.prototype.getShaderPrecisionFormat = function (shaderType, precisionType) {
        this._glCheckError('getShaderPrecisionFormat');
        this._checkArgs('getShaderPrecisionFormat', arguments);
        var precision = this.context.getShaderPrecisionFormatWithShaderTypePrecisionType(shaderType, precisionType);
        return new canvas_plugin_common_1.WebGLShaderPrecisionFormat(precision.rangeMin, precision.rangeMax, precision.precision);
    };
    TNSWebGLRenderingContext.prototype.getShaderSource = function (shader) {
        this._glCheckError('getShaderSource');
        this._checkArgs('getShaderSource', arguments);
        var value = shader ? shader.native : 0;
        return this.context.getShaderSourceWithShader(value);
    };
    TNSWebGLRenderingContext.prototype.getSupportedExtensions = function () {
        this._glCheckError('getSupportedExtensions');
        this._checkArgs('getSupportedExtensions', arguments);
        var extensions = this.context.getSupportedExtensions();
        var array = [];
        var length = extensions.count;
        for (var i = 0; i < length; i++) {
            array.push(extensions.objectAtIndex(i));
        }
        return array;
    };
    TNSWebGLRenderingContext.prototype.getTexParameter = function (target, pname) {
        this._glCheckError('getTexParameter');
        this._checkArgs('getTexParameter', arguments);
        return this.context.getTexParameterWithTargetPname(target, pname);
    };
    TNSWebGLRenderingContext.prototype.getUniformLocation = function (program, name) {
        this._glCheckError('getUniformLocation');
        this._checkArgs('getUniformLocation', arguments);
        var value = program ? program.native : 0;
        var id = this.context.getUniformLocationWithProgramName(value, name);
        if (id === -1) {
            return null;
        }
        ;
        return new canvas_plugin_common_1.WebGLUniformLocation(id);
    };
    TNSWebGLRenderingContext.prototype.getUniform = function (program, location) {
        this._glCheckError('getUniform');
        this._checkArgs('getUniform', arguments);
        var value = program ? program.native : 0;
        var value2 = location ? location.native : 0;
        var result = this.context.getUniformWithProgramLocation(value, value2);
        if (result instanceof NSArray) {
            var array = [];
            var length = result.count;
            for (var i = 0; i < length; i++) {
                array.push(result.objectAtIndex(i));
            }
            return array;
        }
        return result;
    };
    TNSWebGLRenderingContext.prototype.getVertexAttribOffset = function (index, pname) {
        this._glCheckError('getVertexAttribOffset');
        this._checkArgs('getVertexAttribOffset', arguments);
        return this.context.getVertexAttribOffsetWithIndexPname(index, pname);
    };
    TNSWebGLRenderingContext.prototype.getVertexAttrib = function (index, pname) {
        this._glCheckError('getVertexAttrib');
        this._checkArgs('getVertexAttrib', arguments);
        var value = this.context.getVertexAttribWithIndexPname(index, pname);
        if (pname === this.CURRENT_VERTEX_ATTRIB && value instanceof NSArray) {
            var count = value.count;
            var array = [];
            for (var i = 0; i < count; i++) {
                array.push(value.objectAtIndex(i));
            }
            return array;
        }
        return value;
    };
    TNSWebGLRenderingContext.prototype.hint = function (target, mode) {
        this._glCheckError('hint');
        this._checkArgs('hint', arguments);
        this.context.hintWithTargetMode(target, mode);
    };
    TNSWebGLRenderingContext.prototype.isBuffer = function (buffer) {
        this._glCheckError('isBuffer');
        this._checkArgs('isBuffer', arguments);
        var value = buffer ? buffer.native : 0;
        return this.context.isBufferWithBuffer(value);
    };
    TNSWebGLRenderingContext.prototype.isContextLost = function () {
        this._glCheckError('isContextLost');
        this._checkArgs('isContextLost', arguments);
        return false;
    };
    TNSWebGLRenderingContext.prototype.isEnabled = function (cap) {
        this._glCheckError('isEnabled');
        this._checkArgs('isEnabled', arguments);
        return this.context.isEnabledWithCap(cap);
    };
    TNSWebGLRenderingContext.prototype.isFramebuffer = function (framebuffer) {
        this._glCheckError('isFramebuffer');
        this._checkArgs('isFramebuffer', arguments);
        var value = framebuffer ? framebuffer.native : 0;
        return this.context.isFramebufferWithFramebuffer(value);
    };
    TNSWebGLRenderingContext.prototype.isProgram = function (program) {
        this._glCheckError('isProgram');
        this._checkArgs('isProgram', arguments);
        var value = program ? program.native : 0;
        return this.context.isProgramWithProgram(value);
    };
    TNSWebGLRenderingContext.prototype.isRenderbuffer = function (renderbuffer) {
        this._glCheckError('isRenderbuffer');
        this._checkArgs('isRenderbuffer', arguments);
        var value = renderbuffer ? renderbuffer.native : 0;
        return this.context.isRenderbufferWithRenderbuffer(value);
    };
    TNSWebGLRenderingContext.prototype.isShader = function (shader) {
        this._glCheckError('isShader');
        this._checkArgs('isShader', arguments);
        var value = shader ? shader.native : 0;
        return this.context.isShaderWithShader(value);
    };
    TNSWebGLRenderingContext.prototype.isTexture = function (texture) {
        this._glCheckError('isTexture');
        this._checkArgs('isTexture', arguments);
        var value = texture ? texture.native : 0;
        return this.context.isTextureWithTexture(value);
    };
    TNSWebGLRenderingContext.prototype.lineWidth = function (width) {
        this._glCheckError('lineWidth');
        this._checkArgs('lineWidth', arguments);
        this.context.lineWidthWithWidth(width);
    };
    TNSWebGLRenderingContext.prototype.linkProgram = function (program) {
        this._glCheckError('linkProgram');
        this._checkArgs('linkProgram', arguments);
        var value = program ? program.native : 0;
        this.context.linkProgramWithProgram(value);
    };
    TNSWebGLRenderingContext.prototype.pixelStorei = function (pname, param) {
        this._glCheckError('pixelStorei');
        this._checkArgs('pixelStorei', arguments);
        this.context.pixelStoreiWithPnameParam(pname, param);
    };
    TNSWebGLRenderingContext.prototype.polygonOffset = function (factor, units) {
        this._glCheckError('polygonOffset');
        this._checkArgs('polygonOffset', arguments);
        this.context.polygonOffsetWithFactorUnits(factor, units);
    };
    TNSWebGLRenderingContext.prototype.readPixels = function (x, y, width, height, format, type, pixels) {
        this._glCheckError('readPixels');
        this._checkArgs('readPixels', arguments);
        if (pixels && pixels.buffer instanceof ArrayBuffer) {
            if (pixels instanceof Float32Array || pixels instanceof Float64Array) {
                this.context.readPixelsWithXYWidthHeightFormatTypeFloatArray(x, y, width, height, format, type, pixels);
            }
            else if (pixels instanceof Uint16Array || pixels instanceof Int16Array) {
                this.context.readPixelsWithXYWidthHeightFormatTypeShortArray(x, y, width, height, format, type, pixels);
            }
            else if (pixels instanceof Uint8Array) {
                this.context.readPixelsWithXYWidthHeightFormatTypeByteArray(x, y, width, height, format, type, pixels);
            }
        }
        else if (pixels instanceof ArrayBuffer) {
            this.context.readPixelsWithXYWidthHeightFormatTypeByteArray(x, y, width, height, format, type, new Uint8Array(pixels.slice(0)));
        }
    };
    TNSWebGLRenderingContext.prototype.renderbufferStorage = function (target, internalFormat, width, height) {
        this._glCheckError('renderbufferStorage');
        this._checkArgs('renderbufferStorage', arguments);
        if (internalFormat === this.DEPTH_STENCIL) {
            internalFormat = 35056;
        }
        this.context.renderbufferStorageWithTargetInternalFormatWidthHeight(target, internalFormat, width, height);
    };
    TNSWebGLRenderingContext.prototype.sampleCoverage = function (value, invert) {
        this._glCheckError('sampleCoverage');
        this._checkArgs('sampleCoverage', arguments);
        this.context.sampleCoverageWithValueInvert(value, invert);
    };
    TNSWebGLRenderingContext.prototype.scissor = function (x, y, width, height) {
        this._glCheckError('scissor');
        this._checkArgs('scissor', arguments);
        this.context.scissorWithXYWidthHeight(x, y, width, height);
    };
    TNSWebGLRenderingContext.prototype.shaderSource = function (shader, source) {
        this._glCheckError('shaderSource');
        this._checkArgs('shaderSource', arguments);
        var value = shader ? shader.native : 0;
        this.context.shaderSourceWithShaderSource(value, source);
    };
    TNSWebGLRenderingContext.prototype.stencilFuncSeparate = function (face, func, ref, mask) {
        this._glCheckError('stencilFuncSeparate');
        this._checkArgs('stencilFuncSeparate', arguments);
        this.context.stencilFuncSeparateWithFaceFnRefMask(face, func, ref, mask);
    };
    TNSWebGLRenderingContext.prototype.stencilFunc = function (func, ref, mask) {
        this._glCheckError('stencilFunc');
        this._checkArgs('stencilFunc', arguments);
        this.context.stencilFuncWithFnRefMask(func, ref, mask);
    };
    TNSWebGLRenderingContext.prototype.stencilMaskSeparate = function (face, mask) {
        this._glCheckError('stencilMaskSeparate');
        this._checkArgs('stencilMaskSeparate', arguments);
        this.context.stencilMaskSeparateWithFaceMask(face, mask);
    };
    TNSWebGLRenderingContext.prototype.stencilMask = function (mask) {
        this._glCheckError('stencilMask');
        this._checkArgs('stencilMask', arguments);
        this.context.stencilMaskWithMask(mask);
    };
    TNSWebGLRenderingContext.prototype.stencilOpSeparate = function (face, fail, zfail, zpass) {
        this._glCheckError('stencilOpSeparate');
        this._checkArgs('stencilOpSeparate', arguments);
        this.context.stencilOpSeparateWithFaceFailZfailZpass(face, fail, zfail, zpass);
    };
    TNSWebGLRenderingContext.prototype.stencilOp = function (fail, zfail, zpass) {
        this._glCheckError('stencilOp');
        this._checkArgs('stencilOp', arguments);
        this.context.stencilOpWithFailZfailZpass(fail, zfail, zpass);
    };
    TNSWebGLRenderingContext.prototype.texImage2D = function (target, level, internalformat, width, height, border, format, type, pixels) {
        this._glCheckError('texImage2D');
        this._checkArgs('texImage2D', arguments);
        if (arguments.length === 9) {
            if (pixels && pixels.buffer) {
                if (pixels instanceof Float32Array || pixels instanceof Float64Array) {
                    this.context.texImage2DWithTargetLevelInternalformatWidthHeightBorderFormatTypeFloatArray(target, level, internalformat, width, height, border, format, type, pixels);
                }
                else if (pixels instanceof Uint32Array || pixels instanceof Int32Array) {
                    this.context.texImage2DWithTargetLevelInternalformatWidthHeightBorderFormatTypeIntArray(target, level, internalformat, width, height, border, format, type, pixels);
                }
                else if (pixels instanceof Uint16Array || pixels instanceof Int16Array) {
                    this.context.texImage2DWithTargetLevelInternalformatWidthHeightBorderFormatTypeShortArray(target, level, internalformat, width, height, border, format, type, pixels);
                }
                else if (pixels instanceof Uint8Array) {
                    this.context.texImage2DWithTargetLevelInternalformatWidthHeightBorderFormatTypeByteArray(target, level, internalformat, width, height, border, format, type, pixels);
                }
            }
            else if (pixels instanceof ArrayBuffer) {
                this.context.texImage2DWithTargetLevelInternalformatWidthHeightBorderFormatTypeByteArray(target, level, internalformat, width, height, border, format, type, new Uint8Array(pixels.slice(0)));
            }
            else {
                this.context.texImage2DWithTargetLevelInternalformatWidthHeightBorderFormatTypePixels(target, level, internalformat, width, height, border, format, type, pixels);
            }
        }
        else if (arguments.length === 6) {
            if (border instanceof TNSImageAsset_1.TNSImageAsset) {
                this.context.texImage2DWithTargetLevelInternalformatFormatTypeAsset(target, level, internalformat, width, height, border.native);
            }
            else if (border instanceof image_source_1.ImageSource) {
                this.context.texImage2DWithTargetLevelInternalformatFormatTypePixels(target, level, internalformat, width, height, border.ios);
            }
            else if (border instanceof UIImage) {
                this.context.texImage2DWithTargetLevelInternalformatFormatTypePixels(target, level, internalformat, width, height, border);
            }
            else if (border &&
                typeof border.tagName === 'string' &&
                border.tagName === 'IMG') {
                if (border._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                    this.context.texImage2DWithTargetLevelInternalformatFormatTypeAsset(target, level, internalformat, width, height, border._asset.native);
                }
                else if (border._imageSource instanceof image_source_1.ImageSource) {
                    this.context.texImage2DWithTargetLevelInternalformatFormatTypePixels(target, level, internalformat, width, height, border._imageSource.ios);
                }
                else if (border._image instanceof UIImage) {
                    this.context.texImage2DWithTargetLevelInternalformatFormatTypePixels(target, level, internalformat, width, height, border._image);
                }
                else if (typeof border.src === 'string') {
                    var asset = image_source_1.fromFile(border.src);
                    this.context.texImage2DWithTargetLevelInternalformatFormatTypePixels(target, level, internalformat, width, height, asset.ios);
                }
            }
            else {
                this.context.texImage2DWithTargetLevelInternalformatFormatTypeNone(target, level, internalformat, width, height, border);
            }
        }
    };
    TNSWebGLRenderingContext.prototype.texParameterf = function (target, pname, param) {
        this._glCheckError('texParameterf');
        this._checkArgs('texParameterf', arguments);
        this.context.texParameterfWithTargetPnameParam(target, pname, param);
    };
    TNSWebGLRenderingContext.prototype.texParameteri = function (target, pname, param) {
        this._glCheckError('texParameteri');
        this._checkArgs('texParameteri', arguments);
        this.context.texParameteriWithTargetPnameParam(target, pname, param);
    };
    TNSWebGLRenderingContext.prototype.texSubImage2D = function (target, level, xoffset, yoffset, width, height, format, type, pixels) {
        this._glCheckError('texSubImage2D');
        this._checkArgs('texSubImage2D', arguments);
        if (arguments.length === 9) {
            if (pixels && pixels.buffer) {
                if (pixels instanceof Float32Array || pixels instanceof Float64Array) {
                    this.context.texSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatTypeFloatArray(target, level, xoffset, yoffset, width, height, format, type, pixels);
                }
                else if (pixels instanceof Uint16Array || pixels instanceof Int16Array) {
                    this.context.texSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatTypeShortArray(target, level, xoffset, yoffset, width, height, format, type, pixels);
                }
                else if (pixels instanceof Uint8Array) {
                    this.context.texSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatTypeByteArray(target, level, xoffset, yoffset, width, height, format, type, pixels);
                }
            }
            else if (pixels instanceof ArrayBuffer) {
                this.context.texSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatTypeByteArray(target, level, xoffset, yoffset, width, height, format, type, new Uint8Array(pixels.slice(0)));
            }
            else {
                this.context.texSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatTypePixels(target, level, xoffset, yoffset, width, height, format, type, pixels);
            }
        }
        else if (arguments.length === 7) {
            if (format instanceof TNSImageAsset_1.TNSImageAsset) {
                this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypeAsset(target, level, xoffset, yoffset, width, height, format.native);
            }
            else if (format instanceof UIImage) {
                this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypePixels(target, level, xoffset, yoffset, width, height, format);
            }
            else if (format instanceof image_source_1.ImageSource) {
                this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypePixels(target, level, xoffset, yoffset, width, height, format.ios);
            }
            else if (format &&
                typeof format.tagName === 'string' &&
                format.tagName === 'IMG') {
                if (format._imageSource instanceof image_source_1.ImageSource) {
                    this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypePixels(target, level, xoffset, yoffset, width, height, format._imageSource.ios);
                }
                else if (format._image instanceof UIImage) {
                    this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypePixels(target, level, xoffset, yoffset, width, height, format._image);
                }
                else if (format._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                    this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypeAsset(target, level, xoffset, yoffset, width, height, format._asset.native);
                }
                else if (typeof format.src === 'string') {
                    var result = image_source_1.fromFile(format.src);
                    this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypePixels(target, level, xoffset, yoffset, width, height, result ? result.ios : null);
                }
            }
            else {
                this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypeNone(target, level, xoffset, yoffset, width, height, format);
            }
        }
    };
    TNSWebGLRenderingContext.prototype.uniform1f = function (location, v0) {
        this._glCheckError('uniform1f');
        this._checkArgs('uniform1f', arguments);
        this.context.uniform1fWithLocationV0(location.native, v0);
    };
    TNSWebGLRenderingContext.prototype.uniform1iv = function (location, value) {
        this._glCheckError('uniform1iv');
        this._checkArgs('uniform1iv', arguments);
        this.context.uniform1ivWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform1fv = function (location, value) {
        this._glCheckError('uniform1fv');
        this._checkArgs('uniform1fv', arguments);
        if (!(value instanceof Float32Array)) {
            value = new Float32Array(value);
        }
        this.context.uniform1fvWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform1i = function (location, v0) {
        this._glCheckError('uniform1i');
        this._checkArgs('uniform1i', arguments);
        this.context.uniform1iWithLocationV0(location.native, v0);
    };
    TNSWebGLRenderingContext.prototype.uniform2f = function (location, v0, v1) {
        this._glCheckError('uniform2f');
        this._checkArgs('uniform2f', arguments);
        this.context.uniform2fWithLocationV0V1(location.native, v0, v1);
    };
    TNSWebGLRenderingContext.prototype.uniform2iv = function (location, value) {
        this._glCheckError('uniform2iv');
        this._checkArgs('activattachShadereTexture', arguments);
        this.context.uniform2ivWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform2fv = function (location, value) {
        this._glCheckError('uniform2fv');
        this._checkArgs('uniform2fv', arguments);
        if (!(value instanceof Float32Array)) {
            value = new Float32Array(value);
        }
        this.context.uniform2fvWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform2i = function (location, v0, v1) {
        this._glCheckError('uniform2i');
        this._checkArgs('uniform2i', arguments);
        this.context.uniform2iWithLocationV0V1(location.native, v0, v1);
    };
    TNSWebGLRenderingContext.prototype.uniform3f = function (location, v0, v1, v2) {
        this._glCheckError('uniform3f');
        this._checkArgs('uniform3f', arguments);
        this.context.uniform3fWithLocationV0V1V2(location.native, v0, v1, v2);
    };
    TNSWebGLRenderingContext.prototype.uniform3iv = function (location, value) {
        this._glCheckError('uniform3iv');
        this._checkArgs('uniform3iv', arguments);
        this.context.uniform3ivWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform3fv = function (location, value) {
        this._glCheckError('uniform3fv');
        this._checkArgs('uniform3fv', arguments);
        if (!(value instanceof Float32Array)) {
            value = new Float32Array(value);
        }
        this.context.uniform3fvWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform3i = function (location, v0, v1, v2) {
        this._glCheckError('uniform3i');
        this._checkArgs('uniform3i', arguments);
        this.context.uniform3iWithLocationV0V1V2(location.native, v0, v1, v2);
    };
    TNSWebGLRenderingContext.prototype.uniform4f = function (location, v0, v1, v2, v3) {
        this._glCheckError('uniform4f');
        this._checkArgs('uniform4f', arguments);
        this.context.uniform4fWithLocationV0V1V2V3(location.native, v0, v1, v2, v3);
    };
    TNSWebGLRenderingContext.prototype.uniform4iv = function (location, value) {
        this._glCheckError('uniform4iv');
        this._checkArgs('uniform4iv', arguments);
        this.context.uniform4ivWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform4fv = function (location, value) {
        this._glCheckError('uniform4fv');
        this._checkArgs('uniform4fv', arguments);
        if (!(value instanceof Float32Array)) {
            value = new Float32Array(value);
        }
        this.context.uniform4fvWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform4i = function (location, v0, v1, v2, v3) {
        this._glCheckError('uniform4i');
        this._checkArgs('uniform4i', arguments);
        this.context.uniform4iWithLocationV0V1V2V3(location.native, v0, v1, v2, v3);
    };
    TNSWebGLRenderingContext.prototype.uniformMatrix2fv = function (location, transpose, value) {
        this._glCheckError('uniformMatrix2fv');
        this._checkArgs('uniformMatrix2fv', arguments);
        if (!(value instanceof Float32Array)) {
            value = new Float32Array(value);
        }
        this.context.uniformMatrix2fvWithLocationTransposeValue(location.native, transpose, value);
    };
    TNSWebGLRenderingContext.prototype.uniformMatrix3fv = function (location, transpose, value) {
        this._glCheckError('uniformMatrix3fv');
        this._checkArgs('uniformMatrix3fv', arguments);
        if (!(value instanceof Float32Array)) {
            value = new Float32Array(value);
        }
        this.context.uniformMatrix3fvWithLocationTransposeValue(location.native, transpose, value);
    };
    TNSWebGLRenderingContext.prototype.uniformMatrix4fv = function (location, transpose, value) {
        this._glCheckError('uniformMatrix4fv');
        this._checkArgs('uniformMatrix4fv', arguments);
        if (!(value instanceof Float32Array)) {
            value = new Float32Array(value);
        }
        this.context.uniformMatrix4fvWithLocationTransposeValue(location.native, transpose, value);
    };
    TNSWebGLRenderingContext.prototype.useProgram = function (program) {
        this._glCheckError('useProgram');
        this._checkArgs('useProgram', arguments);
        var value = program ? program.native : 0;
        this.context.useProgramWithProgram(value);
    };
    TNSWebGLRenderingContext.prototype.validateProgram = function (program) {
        this._glCheckError('validateProgram');
        this._checkArgs('validateProgram', arguments);
        var value = program ? program.native : 0;
        this.context.validateProgramWithProgram(value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib1f = function (index, v0) {
        this._glCheckError('vertexAttrib1f');
        this._checkArgs('vertexAttrib1f', arguments);
        this.context.vertexAttrib1fWithIndexV0(index, v0);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib1fv = function (index, value) {
        this._glCheckError('vertexAttrib1fv');
        this._checkArgs('vertexAttrib1fv', arguments);
        this.context.vertexAttrib1fvWithIndexValue(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib2f = function (index, v0, v1) {
        this._glCheckError('vertexAttrib2f');
        this._checkArgs('vertexAttrib2f', arguments);
        this.context.vertexAttrib2fWithIndexV0V1(index, v0, v1);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib2fv = function (index, value) {
        this._glCheckError('vertexAttrib2fv');
        this._checkArgs('vertexAttrib2fv', arguments);
        this.context.vertexAttrib2fvWithIndexValue(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib3f = function (index, v0, v1, v2) {
        this._glCheckError('vertexAttrib3f');
        this._checkArgs('vertexAttrib3f', arguments);
        this.context.vertexAttrib3fWithIndexV0V1V2(index, v0, v1, v2);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib3fv = function (index, value) {
        this._glCheckError('vertexAttrib3fv');
        this._checkArgs('vertexAttrib3fv', arguments);
        this.context.vertexAttrib3fvWithIndexValue(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib4f = function (index, v0, v1, v2, v3) {
        this._glCheckError('vertexAttrib4f');
        this._checkArgs('vertexAttrib4f', arguments);
        this.context.vertexAttrib4fWithIndexV0V1V2V3(index, v0, v1, v2, v3);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib4fv = function (index, value) {
        this._glCheckError('vertexAttrib4fv');
        this._checkArgs('vertexAttrib4fv', arguments);
        this.context.vertexAttrib4fvWithIndexValue(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttribPointer = function (index, size, type, normalized, stride, offset) {
        this._glCheckError('vertexAttribPointer');
        this._checkArgs('vertexAttribPointer', arguments);
        this.context.vertexAttribPointerWithIndexSizeTypeNormalizedStrideOffset(index, size, type, normalized, stride, offset);
    };
    TNSWebGLRenderingContext.prototype.viewport = function (x, y, width, height) {
        this._glCheckError('viewport');
        this._checkArgs('viewport', arguments);
        this.context.viewportWithXYWidthHeight(x, y, width, height);
    };
    TNSWebGLRenderingContext.isDebug = false;
    TNSWebGLRenderingContext.filter = 'both';
    return TNSWebGLRenderingContext;
}(canvas_plugin_common_1.TNSWebGLRenderingContextBase));
exports.TNSWebGLRenderingContext = TNSWebGLRenderingContext;
//# sourceMappingURL=TNSWebGLRenderingContext.ios.js.map